diff --git a/core/hdd/inc/wlan_hdd_cfg.h b/core/hdd/inc/wlan_hdd_cfg.h
index 45d3df1138c1..034dd2db90e5 100644
--- a/core/hdd/inc/wlan_hdd_cfg.h
+++ b/core/hdd/inc/wlan_hdd_cfg.h
@@ -596,29 +596,6 @@ enum hdd_dot11_mode {
#define CFG_ENABLE_DFS_CHNL_SCAN_MAX (1)
#define CFG_ENABLE_DFS_CHNL_SCAN_DEFAULT (1)
-/*
- *
- * pmkidModes - Enable PMKID modes
- * This INI is used to enable PMKID feature options
- * @Min: 0
- * @Max: 3
- * @Default: 3
- *
- * Related: None
- *
- * Supported Feature: Scan
- *
- * Usage: External
- *
- *
- */
-#define CFG_PMKID_MODES_NAME "pmkidModes"
-#define CFG_PMKID_MODES_MIN (0x0)
-#define CFG_PMKID_MODES_MAX (0x3)
-#define CFG_PMKID_MODES_DEFAULT (0x3)
-#define CFG_PMKID_MODES_OKC (0x1)
-#define CFG_PMKID_MODES_PMKSA_CACHING (0x2)
-
/*
*
* gEnableDFSPnoChnlScan - enable dfs channels in PNO scan
@@ -3178,30 +3155,6 @@ enum hdd_dot11_mode {
#define CFG_WOW_DATA_INACTIVITY_TIMEOUT_MAX (255)
#define CFG_WOW_DATA_INACTIVITY_TIMEOUT_DEFAULT (50)
-/*
- *
- * gStaKeepAlivePeriod - Sends NULL frame to AP periodically in
- * seconds to notify STA's existence
- * @Min: 0
- * @Max: 65535
- * @Default: 30
- *
- * This ini is used to send default NULL frame to AP
- *
- * Related: None
- *
- * Supported Feature: STA
- *
- * Usage: Internal/External
- *
- *
- */
-
-#define CFG_INFRA_STA_KEEP_ALIVE_PERIOD_NAME "gStaKeepAlivePeriod"
-#define CFG_INFRA_STA_KEEP_ALIVE_PERIOD_MIN (0)
-#define CFG_INFRA_STA_KEEP_ALIVE_PERIOD_MAX (65535)
-#define CFG_INFRA_STA_KEEP_ALIVE_PERIOD_DEFAULT (60)
-
/**
* enum station_keepalive_method - available keepalive methods for stations
* @HDD_STA_KEEPALIVE_NULL_DATA: null data packet
@@ -3991,28 +3944,6 @@ enum station_keepalive_method {
#define CFG_QOS_WMM_TS_INFO_ACK_POLICY_MAX (0x01)
#define CFG_QOS_WMM_TS_INFO_ACK_POLICY_DEFAULT (0x00)
-/*
- *
- * SingleTIDRC - Set replay counter for all TID's
- * @Min: 0
- * @Max: 1
- * @Default: 1
- *
- * This ini is used to set replay counter for all TID's
- *
- * Related: None.
- *
- * Supported Feature: WMM
- *
- * Usage: Internal/External
- *
- *
- */
-#define CFG_SINGLE_TID_RC_NAME "SingleTIDRC"
-#define CFG_SINGLE_TID_RC_MIN (0) /* Separate replay counter for all TID */
-#define CFG_SINGLE_TID_RC_MAX (1) /* Single replay counter for all TID */
-#define CFG_SINGLE_TID_RC_DEFAULT (1)
-
/*
*
* gAddTSWhenACMIsOff - Set ACM value for AC
@@ -4694,32 +4625,6 @@ enum hdd_link_speed_rpt_type {
#define CFG_ENABLE_BT_CHAIN_SEPARATION_MAX (1)
#define CFG_ENABLE_BT_CHAIN_SEPARATION_DEFAULT (0)
-/*
- *
- * gStaPrefer80MHzOver160MHz - set Sta perferance to connect in 80HZ/160HZ
- * @Min: 0
- * @Max: 1
- * @Default: 1
- *
- * This ini is used to set Sta perferance to connect in 80HZ/160HZ
- *
- * 0 - Connects in 160MHz 1x1 when AP is 160MHz 2x2
- * 1 - Connects in 80MHz 2x2 when AP is 160MHz 2x2
- *
- * Related: NA
- *
- * Supported Feature: 11AC
- *
- * Usage: External
- *
- *
- */
-
-#define CFG_STA_PREFER_80MHZ_OVER_160MHZ "gStaPrefer80MHzOver160MHz"
-#define CFG_STA_PREFER_80MHZ_OVER_160MHZ_MIN (0)
-#define CFG_STA_PREFER_80MHZ_OVER_160MHZ_MAX (1)
-#define CFG_STA_PREFER_80MHZ_OVER_160MHZ_DEFAULT (1)
-
/*
*
* gVdevTypeNss_2g - set Number of streams per VDEV for 2G band.
@@ -5138,31 +5043,6 @@ enum hdd_link_speed_rpt_type {
#define CFG_ENABLE_OVERLAP_CH_MAX (1)
#define CFG_ENABLE_OVERLAP_CH_DEFAULT (0)
-/*
- *
- * gEnable5gEBT - Enables/disables 5G early beacon termination. When enabled
- * terminate the reception of beacon if the TIM element is
- * clear for the power saving
- * @Min: 0
- * @Max: 1
- * @Default: 1
- *
- * This ini is used to set default 5G early beacon termination
- *
- * Related: None
- *
- * Supported Feature: STA
- *
- * Usage: Internal/External
- *
- *
- */
-
-#define CFG_PPS_ENABLE_5G_EBT "gEnable5gEBT"
-#define CFG_PPS_ENABLE_5G_EBT_FEATURE_MIN (0)
-#define CFG_PPS_ENABLE_5G_EBT_FEATURE_MAX (1)
-#define CFG_PPS_ENABLE_5G_EBT_FEATURE_DEFAULT (1)
-
#define CFG_ENABLE_MEMORY_DEEP_SLEEP "gEnableMemDeepSleep"
#define CFG_ENABLE_MEMORY_DEEP_SLEEP_MIN (0)
#define CFG_ENABLE_MEMORY_DEEP_SLEEP_MAX (1)
@@ -6623,29 +6503,6 @@ enum hdd_link_speed_rpt_type {
#define CFG_RA_RATE_LIMIT_INTERVAL_DEFAULT (60) /*60 SEC */
#endif
-/*
- *
- * gIgnorePeerErpInfo - Used for ignore peer infrormation
- * @Min: 0
- * @Max: 1
- * @Default: 0
- *
- * This ini is used to ignore default peer info
- *
- * Related: None
- *
- * Supported Feature: STA
- *
- * Usage: Internal/External
- *
- *
- */
-
-#define CFG_IGNORE_PEER_ERP_INFO_NAME "gIgnorePeerErpInfo"
-#define CFG_IGNORE_PEER_ERP_INFO_MIN (0)
-#define CFG_IGNORE_PEER_ERP_INFO_MAX (1)
-#define CFG_IGNORE_PEER_ERP_INFO_DEFAULT (0)
-
/*
*
* gEnableMemoryDebug - Enables the memory debug
@@ -7200,31 +7057,6 @@ enum hdd_link_speed_rpt_type {
#define CFG_DHCP_SERVER_IP_DEFAULT ""
#endif /* DHCP_SERVER_OFFLOAD */
-/*
- *
- * gSendDeauthBeforeCon - It will send deauth before connection
- * @Min: 0
- * @Max: 1
- * @Default: 0
- *
- * This ini is used to set default DeauthBeforeCon
- * If last disconnection was due to HB failure and we reconnect
- * to same AP next time, send Deauth before starting connection
- *
- * Related: None
- *
- * Supported Feature: STA
- *
- * Usage: Internal/External
- *
- *
- */
-
-#define CFG_ENABLE_DEAUTH_BEFORE_CONNECTION "gSendDeauthBeforeCon"
-#define CFG_ENABLE_DEAUTH_BEFORE_CONNECTION_MIN (0)
-#define CFG_ENABLE_DEAUTH_BEFORE_CONNECTION_MAX (1)
-#define CFG_ENABLE_DEAUTH_BEFORE_CONNECTION_DEFAULT (0)
-
/*
*
* gEnableCustomConcRule1 - Enable custom concurrency rule1.
@@ -7698,23 +7530,6 @@ enum hdd_link_speed_rpt_type {
#define CFG_FINE_TIME_MEAS_CAPABILITY_MAX (0x00BD)
#define CFG_FINE_TIME_MEAS_CAPABILITY_DEFAULT (0x000D)
-/**
- * enum dot11p_mode - The 802.11p mode of operation
- * @WLAN_HDD_11P_DISABLED: 802.11p mode is disabled
- * @WLAN_HDD_11P_STANDALONE: 802.11p-only operation
- * @WLAN_HDD_11P_CONCURRENT: 802.11p and WLAN operate concurrently
- */
-enum dot11p_mode {
- WLAN_HDD_11P_DISABLED = 0,
- WLAN_HDD_11P_STANDALONE,
- WLAN_HDD_11P_CONCURRENT,
-};
-
-#define CFG_DOT11P_MODE_NAME "gDot11PMode"
-#define CFG_DOT11P_MODE_DEFAULT (WLAN_HDD_11P_DISABLED)
-#define CFG_DOT11P_MODE_MIN (WLAN_HDD_11P_DISABLED)
-#define CFG_DOT11P_MODE_MAX (WLAN_HDD_11P_CONCURRENT)
-
/*
*
* etsi13_srd_chan_in_master_mode - Enable/disable ETSI SRD channels in
@@ -7739,32 +7554,6 @@ enum dot11p_mode {
#define CFG_ETSI13_SRD_CHAN_IN_MASTER_MODE_MIN (0)
#define CFG_ETSI13_SRD_CHAN_IN_MASTER_MODE_MAX (1)
-/*
- *
- * gEnable_go_cts2self_for_sta - Indicate firmware to stop NOA and
- * start using cts2self
- * @Min: 1
- * @Max: 1
- * @Default: 0
- *
- * When gEnable_go_cts2self_for_sta is
- * enabled then if a legacy client connects to P2P GO,
- * Host will send a WMI VDEV command to FW to stop using NOA for P2P GO
- * and start using CTS2SELF.
- *
- *
- * Supported Feature: P2P
- *
- *
- * Usage: Internal/External
- *
- *
- */
-#define CFG_ENABLE_GO_CTS2SELF_FOR_STA "gEnable_go_cts2self_for_sta"
-#define CFG_ENABLE_GO_CTS2SELF_FOR_STA_DEFAULT (0)
-#define CFG_ENABLE_GO_CTS2SELF_FOR_STA_MIN (0)
-#define CFG_ENABLE_GO_CTS2SELF_FOR_STA_MAX (1)
-
#define CFG_CE_CLASSIFY_ENABLE_NAME "gCEClassifyEnable"
#define CFG_CE_CLASSIFY_ENABLE_MIN (0)
#define CFG_CE_CLASSIFY_ENABLE_MAX (1)
@@ -8533,11 +8322,6 @@ enum dot11p_mode {
#define CFG_SUB_20_CHANNEL_WIDTH_MAX (WLAN_SUB_20_CH_WIDTH_10)
#define CFG_SUB_20_CHANNEL_WIDTH_DEFAULT (WLAN_SUB_20_CH_WIDTH_NONE)
-#define CFG_TGT_GTX_USR_CFG_NAME "tgt_gtx_usr_cfg"
-#define CFG_TGT_GTX_USR_CFG_MIN (0)
-#define CFG_TGT_GTX_USR_CFG_MAX (32)
-#define CFG_TGT_GTX_USR_CFG_DEFAULT (32)
-
#define CFG_SAP_INTERNAL_RESTART_NAME "gEnableSapInternalRestart"
#define CFG_SAP_INTERNAL_RESTART_MIN (0)
#define CFG_SAP_INTERNAL_RESTART_MAX (1)
@@ -10212,29 +9996,6 @@ enum hdd_wext_control {
#define CFG_ENABLE_ANI_MAX (1)
#define CFG_ENABLE_ANI_DEFAULT (1)
-/*
- *
- * g_qcn_ie_support - QCN IE Support
- * @Min: 0 (disabled)
- * @Max: 1 (enabled)
- * @Default: 1 (enabled)
- *
- * This config item is used to support QCN IE in probe/assoc/reassoc request
- * for STA mode. QCN IE support is not added for SAP mode.
- *
- * Related: N/A
- *
- * Supported Feature: N/A
- *
- * Usage: Internal/External
- *
- *
- */
-#define CFG_QCN_IE_SUPPORT_NAME "g_qcn_ie_support"
-#define CFG_QCN_IE_SUPPORT_MIN 0
-#define CFG_QCN_IE_SUPPORT_MAX 1
-#define CFG_QCN_IE_SUPPORT_DEFAULT 1
-
/*
*
* gTimerMultiplier - Scale QDF timers by this value
@@ -10560,28 +10321,6 @@ enum hdd_wext_control {
#define CFG_SAP_CH_SWITCH_MODE_MAX (1)
#define CFG_SAP_CH_SWITCH_MODE_DEFAULT (1)
-/*
- *
- * g_fils_max_chan_guard_time - Set maximum channel guard time(ms)
- * @Min: 0
- * @Max: 10
- * @Default: 0
- *
- * This ini is used to set maximum channel guard time in milli seconds
- *
- * Related: None
- *
- * Supported Feature: FILS
- *
- * Usage: External
- *
- *
- */
-#define CFG_FILS_MAX_CHAN_GUARD_TIME_NAME "g_fils_max_chan_guard_time"
-#define CFG_FILS_MAX_CHAN_GUARD_TIME_MIN (0)
-#define CFG_FILS_MAX_CHAN_GUARD_TIME_MAX (10)
-#define CFG_FILS_MAX_CHAN_GUARD_TIME_DEFAULT (0)
-
/**
* gSetRTSForSIFSBursting - set rts for sifs bursting
* @Min: 0
@@ -11967,30 +11706,6 @@ enum hdd_external_acs_policy {
#define CFG_ENABLE_SCORING_FOR_ROAM_MIN (0)
#define CFG_ENABLE_SCORING_FOR_ROAM_MAX (1)
-/*
- *
- * force_rsne_override - force rsnie override from user
- * @Min: 0
- * @Max: 1
- * @Default: 0
- *
- * This ini is used to enable/disable test mode to force rsne override used in
- * security enhancement test cases to pass the RSNIE sent by user in
- * assoc request.
- *
- * Related: None
- *
- * Supported Feature: STA
- *
- * Usage: internal
- *
- *
- */
-#define CFG_FORCE_RSNE_OVERRIDE_NAME "force_rsne_override"
-#define CFG_FORCE_RSNE_OVERRIDE_MIN (0)
-#define CFG_FORCE_RSNE_OVERRIDE_MAX (1)
-#define CFG_FORCE_RSNE_OVERRIDE_DEFAULT (0)
-
/*
*
* gChanSwitchHostapdRateEnabled - Enable/disable hostapd rate when doing SAP
@@ -13379,7 +13094,6 @@ struct hdd_config {
uint8_t RoamRssiDiff;
int32_t rssi_abs_thresh;
bool isWESModeEnabled;
- uint32_t pmkid_modes;
bool isRoamOffloadScanEnabled;
bool bImplicitQosEnabled;
@@ -13418,7 +13132,6 @@ struct hdd_config {
/* Control for Replay counetr. value 1 means
* single replay counter for all TID
*/
- bool bSingleTidRc;
bool fhostArpOffload;
enum pmo_hw_filter_mode hw_filter_mode_bitmap;
bool ssdp;
@@ -13441,7 +13154,6 @@ struct hdd_config {
bool AddTSWhenACMIsOff;
- uint32_t infraStaKeepAlivePeriod;
uint8_t nBandCapability;
bool teleBcnWakeupEn;
@@ -13550,7 +13262,6 @@ struct hdd_config {
bool enableTxSTBC;
uint8_t enable_tx_ldpc;
uint8_t enable_rx_ldpc;
- bool enable5gEBT;
bool prevent_link_down;
uint8_t scanAgingTimeout;
uint8_t disableLDPCWithTxbfAP;
@@ -13749,12 +13460,10 @@ struct hdd_config {
uint8_t go_11ac_override;
uint8_t sap_dot11mc;
uint8_t prefer_non_dfs_on_radar;
- bool ignore_peer_erp_info;
uint8_t multicast_host_fw_msgs;
uint8_t conc_system_pref;
uint32_t dbs_selection_policy;
uint32_t vdev_priority_list;
- bool send_deauth_before_con;
bool tso_enable;
bool lro_enable;
bool gro_enable;
@@ -13768,7 +13477,6 @@ struct hdd_config {
#ifdef WLAN_FEATURE_FASTPATH
bool fastpath_enable;
#endif
- uint8_t dot11p_mode;
bool etsi13_srd_chan_in_master_mode;
uint8_t rx_mode;
uint8_t num_dp_rx_threads;
@@ -13862,7 +13570,6 @@ struct hdd_config {
bool bug_on_reinit_failure;
uint32_t iface_change_wait_time;
/* parameter to control GTX */
- uint32_t tgt_gtx_usr_cfg;
enum cfg_sub_20_channel_width enable_sub_20_channel_width;
bool indoor_channel_support;
/* control marking indoor channel passive to disable */
@@ -13873,8 +13580,6 @@ struct hdd_config {
uint16_t sap_tx_leakage_threshold;
bool multicast_replay_filter;
bool goptimize_chan_avoid_event;
- bool enable_go_cts2self_for_sta;
- bool sta_prefer_80MHz_over_160MHz;
bool fw_timeout_crash;
/* beacon count before channel switch */
uint8_t sap_chanswitch_beacon_cnt;
@@ -13914,7 +13619,6 @@ struct hdd_config {
#endif
uint32_t arp_ac_category;
bool ani_enabled;
- bool qcn_ie_support;
bool tx_orphan_enable;
bool probe_req_ie_whitelist;
@@ -13933,7 +13637,6 @@ struct hdd_config {
uint32_t probe_req_voui[MAX_PROBE_REQ_OUIS];
uint32_t timer_multiplier;
- uint8_t fils_max_chan_guard_time;
uint8_t scan_backoff_multiplier;
bool mawc_nlo_enabled;
uint32_t mawc_nlo_exp_backoff_ratio;
@@ -14004,7 +13707,6 @@ struct hdd_config {
uint32_t oce_wan_score_slots11_to_8;
uint32_t oce_wan_score_slots15_to_12;
bool enable_scoring_for_roam;
- bool force_rsne_override;
bool is_fils_enabled;
uint16_t wlm_latency_enable;
uint16_t wlm_latency_level;
diff --git a/core/hdd/src/wlan_hdd_cfg.c b/core/hdd/src/wlan_hdd_cfg.c
index d31bdeb84618..706f01de27af 100644
--- a/core/hdd/src/wlan_hdd_cfg.c
+++ b/core/hdd/src/wlan_hdd_cfg.c
@@ -1012,13 +1012,6 @@ struct reg_table_entry g_registry_table[] = {
CFG_ENABLE_WES_MODE_NAME_MIN,
CFG_ENABLE_WES_MODE_NAME_MAX,
cb_notify_set_wes_mode, 0),
- REG_VARIABLE(CFG_PMKID_MODES_NAME, WLAN_PARAM_Integer,
- struct hdd_config, pmkid_modes,
- VAR_FLAGS_OPTIONAL |
- VAR_FLAGS_RANGE_CHECK_ASSUME_DEFAULT,
- CFG_PMKID_MODES_DEFAULT,
- CFG_PMKID_MODES_MIN,
- CFG_PMKID_MODES_MAX),
REG_DYNAMIC_VARIABLE(CFG_ROAM_SCAN_OFFLOAD_ENABLED, WLAN_PARAM_Integer,
struct hdd_config, isRoamOffloadScanEnabled,
@@ -1474,13 +1467,6 @@ struct reg_table_entry g_registry_table[] = {
CFG_RA_RATE_LIMIT_INTERVAL_MAX),
#endif
- REG_VARIABLE(CFG_IGNORE_PEER_ERP_INFO_NAME, WLAN_PARAM_Integer,
- struct hdd_config, ignore_peer_erp_info,
- VAR_FLAGS_OPTIONAL | VAR_FLAGS_RANGE_CHECK_ASSUME_DEFAULT,
- CFG_IGNORE_PEER_ERP_INFO_DEFAULT,
- CFG_IGNORE_PEER_ERP_INFO_MIN,
- CFG_IGNORE_PEER_ERP_INFO_MAX),
-
REG_VARIABLE(CFG_ENABLE_HOST_SSDP_NAME, WLAN_PARAM_Integer,
struct hdd_config, ssdp,
VAR_FLAGS_OPTIONAL | VAR_FLAGS_RANGE_CHECK_ASSUME_DEFAULT,
@@ -1519,13 +1505,6 @@ struct reg_table_entry g_registry_table[] = {
CFG_QOS_WMM_TS_INFO_ACK_POLICY_MIN,
CFG_QOS_WMM_TS_INFO_ACK_POLICY_MAX),
- REG_VARIABLE(CFG_SINGLE_TID_RC_NAME, WLAN_PARAM_Integer,
- struct hdd_config, bSingleTidRc,
- VAR_FLAGS_OPTIONAL | VAR_FLAGS_RANGE_CHECK_ASSUME_DEFAULT,
- CFG_SINGLE_TID_RC_DEFAULT,
- CFG_SINGLE_TID_RC_MIN,
- CFG_SINGLE_TID_RC_MAX),
-
REG_VARIABLE(CFG_TELE_BCN_WAKEUP_EN_NAME, WLAN_PARAM_Integer,
struct hdd_config, teleBcnWakeupEn,
VAR_FLAGS_OPTIONAL | VAR_FLAGS_RANGE_CHECK_ASSUME_DEFAULT,
@@ -1533,13 +1512,6 @@ struct reg_table_entry g_registry_table[] = {
CFG_TELE_BCN_WAKEUP_EN_MIN,
CFG_TELE_BCN_WAKEUP_EN_MAX),
- REG_VARIABLE(CFG_INFRA_STA_KEEP_ALIVE_PERIOD_NAME, WLAN_PARAM_Integer,
- struct hdd_config, infraStaKeepAlivePeriod,
- VAR_FLAGS_OPTIONAL | VAR_FLAGS_RANGE_CHECK_ASSUME_DEFAULT,
- CFG_INFRA_STA_KEEP_ALIVE_PERIOD_DEFAULT,
- CFG_INFRA_STA_KEEP_ALIVE_PERIOD_MIN,
- CFG_INFRA_STA_KEEP_ALIVE_PERIOD_MAX),
-
REG_VARIABLE(CFG_STA_KEEPALIVE_METHOD_NAME, WLAN_PARAM_Integer,
struct hdd_config, sta_keepalive_method,
VAR_FLAGS_OPTIONAL | VAR_FLAGS_RANGE_CHECK_ASSUME_DEFAULT,
@@ -1979,13 +1951,6 @@ struct reg_table_entry g_registry_table[] = {
CFG_ENABLE_BT_CHAIN_SEPARATION_MIN,
CFG_ENABLE_BT_CHAIN_SEPARATION_MAX),
- REG_VARIABLE(CFG_STA_PREFER_80MHZ_OVER_160MHZ, WLAN_PARAM_Integer,
- struct hdd_config, sta_prefer_80MHz_over_160MHz,
- VAR_FLAGS_OPTIONAL | VAR_FLAGS_RANGE_CHECK_ASSUME_DEFAULT,
- CFG_STA_PREFER_80MHZ_OVER_160MHZ_DEFAULT,
- CFG_STA_PREFER_80MHZ_OVER_160MHZ_MIN,
- CFG_STA_PREFER_80MHZ_OVER_160MHZ_MAX),
-
REG_VARIABLE(CFG_VDEV_TYPE_NSS_5G, WLAN_PARAM_Integer,
struct hdd_config, vdev_type_nss_5g,
VAR_FLAGS_OPTIONAL | VAR_FLAGS_RANGE_CHECK_ASSUME_DEFAULT,
@@ -2116,13 +2081,6 @@ struct reg_table_entry g_registry_table[] = {
CFG_ENABLE_TX_STBC_MIN,
CFG_ENABLE_TX_STBC_MAX),
- REG_VARIABLE(CFG_PPS_ENABLE_5G_EBT, WLAN_PARAM_Integer,
- struct hdd_config, enable5gEBT,
- VAR_FLAGS_OPTIONAL | VAR_FLAGS_RANGE_CHECK_ASSUME_DEFAULT,
- CFG_PPS_ENABLE_5G_EBT_FEATURE_DEFAULT,
- CFG_PPS_ENABLE_5G_EBT_FEATURE_MIN,
- CFG_PPS_ENABLE_5G_EBT_FEATURE_MAX),
-
REG_VARIABLE(CFG_PREVENT_LINK_DOWN_NAME, WLAN_PARAM_Integer,
struct hdd_config, prevent_link_down,
VAR_FLAGS_OPTIONAL | VAR_FLAGS_RANGE_CHECK_ASSUME_DEFAULT,
@@ -3066,13 +3024,6 @@ struct reg_table_entry g_registry_table[] = {
(void *)CFG_DHCP_SERVER_IP_DEFAULT),
#endif /* DHCP_SERVER_OFFLOAD */
- REG_VARIABLE(CFG_ENABLE_DEAUTH_BEFORE_CONNECTION, WLAN_PARAM_Integer,
- struct hdd_config, send_deauth_before_con,
- VAR_FLAGS_OPTIONAL | VAR_FLAGS_RANGE_CHECK_ASSUME_DEFAULT,
- CFG_ENABLE_DEAUTH_BEFORE_CONNECTION_DEFAULT,
- CFG_ENABLE_DEAUTH_BEFORE_CONNECTION_MIN,
- CFG_ENABLE_DEAUTH_BEFORE_CONNECTION_MAX),
-
REG_VARIABLE(CFG_ENABLE_MAC_ADDR_SPOOFING, WLAN_PARAM_Integer,
struct hdd_config, enable_mac_spoofing,
VAR_FLAGS_OPTIONAL | VAR_FLAGS_RANGE_CHECK_ASSUME_DEFAULT,
@@ -3255,13 +3206,6 @@ struct reg_table_entry g_registry_table[] = {
CFG_MAX_SCAN_COUNT_MIN,
CFG_MAX_SCAN_COUNT_MAX),
- REG_VARIABLE(CFG_DOT11P_MODE_NAME, WLAN_PARAM_Integer,
- struct hdd_config, dot11p_mode,
- VAR_FLAGS_OPTIONAL | VAR_FLAGS_RANGE_CHECK_ASSUME_DEFAULT,
- CFG_DOT11P_MODE_DEFAULT,
- CFG_DOT11P_MODE_MIN,
- CFG_DOT11P_MODE_MAX),
-
REG_VARIABLE(CFG_ETSI13_SRD_CHAN_IN_MASTER_MODE, WLAN_PARAM_Integer,
struct hdd_config, etsi13_srd_chan_in_master_mode,
VAR_FLAGS_OPTIONAL | VAR_FLAGS_RANGE_CHECK_ASSUME_DEFAULT,
@@ -3540,14 +3484,6 @@ struct reg_table_entry g_registry_table[] = {
CFG_ENABLE_EDCA_INI_MIN,
CFG_ENABLE_EDCA_INI_MAX),
- REG_VARIABLE(CFG_ENABLE_GO_CTS2SELF_FOR_STA, WLAN_PARAM_Integer,
- struct hdd_config, enable_go_cts2self_for_sta,
- VAR_FLAGS_OPTIONAL |
- VAR_FLAGS_RANGE_CHECK_ASSUME_DEFAULT,
- CFG_ENABLE_GO_CTS2SELF_FOR_STA_DEFAULT,
- CFG_ENABLE_GO_CTS2SELF_FOR_STA_MIN,
- CFG_ENABLE_GO_CTS2SELF_FOR_STA_MAX),
-
REG_VARIABLE(CFG_EDCA_VO_CWMIN_VALUE_NAME, WLAN_PARAM_Integer,
struct hdd_config, edca_vo_cwmin,
VAR_FLAGS_OPTIONAL |
@@ -3760,13 +3696,6 @@ struct reg_table_entry g_registry_table[] = {
CFG_SUB_20_CHANNEL_WIDTH_MIN,
CFG_SUB_20_CHANNEL_WIDTH_MAX),
- REG_VARIABLE(CFG_TGT_GTX_USR_CFG_NAME, WLAN_PARAM_Integer,
- struct hdd_config, tgt_gtx_usr_cfg,
- VAR_FLAGS_OPTIONAL | VAR_FLAGS_RANGE_CHECK_ASSUME_DEFAULT,
- CFG_TGT_GTX_USR_CFG_DEFAULT,
- CFG_TGT_GTX_USR_CFG_MIN,
- CFG_TGT_GTX_USR_CFG_MAX),
-
REG_VARIABLE(CFG_ADAPT_DWELL_PASMON_INTVAL_NAME, WLAN_PARAM_Integer,
struct hdd_config, adapt_dwell_passive_mon_intval,
VAR_FLAGS_OPTIONAL | VAR_FLAGS_RANGE_CHECK_ASSUME_DEFAULT,
@@ -4092,13 +4021,6 @@ struct reg_table_entry g_registry_table[] = {
CFG_ENABLE_ANI_MIN,
CFG_ENABLE_ANI_MAX),
- REG_VARIABLE(CFG_QCN_IE_SUPPORT_NAME, WLAN_PARAM_Integer,
- struct hdd_config, qcn_ie_support,
- VAR_FLAGS_OPTIONAL | VAR_FLAGS_RANGE_CHECK_ASSUME_DEFAULT,
- CFG_QCN_IE_SUPPORT_DEFAULT,
- CFG_QCN_IE_SUPPORT_MIN,
- CFG_QCN_IE_SUPPORT_MAX),
-
REG_VARIABLE(CFG_TIMER_MULTIPLIER_NAME, WLAN_PARAM_Integer,
struct hdd_config, timer_multiplier,
VAR_FLAGS_OPTIONAL | VAR_FLAGS_RANGE_CHECK_ASSUME_DEFAULT,
@@ -4174,13 +4096,6 @@ struct reg_table_entry g_registry_table[] = {
VAR_FLAGS_OPTIONAL,
(void *)CFG_PROBE_REQ_OUI_DEFAULT),
- REG_VARIABLE(CFG_FILS_MAX_CHAN_GUARD_TIME_NAME, WLAN_PARAM_Integer,
- struct hdd_config, fils_max_chan_guard_time,
- VAR_FLAGS_OPTIONAL | VAR_FLAGS_RANGE_CHECK_ASSUME_DEFAULT,
- CFG_FILS_MAX_CHAN_GUARD_TIME_DEFAULT,
- CFG_FILS_MAX_CHAN_GUARD_TIME_MIN,
- CFG_FILS_MAX_CHAN_GUARD_TIME_MAX),
-
REG_VARIABLE(CFG_SCAN_BACKOFF_MULTIPLIER_NAME, WLAN_PARAM_Integer,
struct hdd_config, scan_backoff_multiplier,
VAR_FLAGS_OPTIONAL | VAR_FLAGS_RANGE_CHECK_ASSUME_DEFAULT,
@@ -4730,13 +4645,6 @@ struct reg_table_entry g_registry_table[] = {
CFG_ENABLE_SCORING_FOR_ROAM_MIN,
CFG_ENABLE_SCORING_FOR_ROAM_MAX),
- REG_VARIABLE(CFG_FORCE_RSNE_OVERRIDE_NAME, WLAN_PARAM_Integer,
- struct hdd_config, force_rsne_override,
- VAR_FLAGS_OPTIONAL | VAR_FLAGS_RANGE_CHECK_ASSUME_DEFAULT,
- CFG_FORCE_RSNE_OVERRIDE_DEFAULT,
- CFG_FORCE_RSNE_OVERRIDE_MIN,
- CFG_FORCE_RSNE_OVERRIDE_MAX),
-
REG_VARIABLE(CFG_MBO_CANDIDATE_RSSI_THRESHOLD_NAME,
WLAN_PARAM_SignedInteger, struct hdd_config,
mbo_candidate_rssi_thres,
@@ -6575,12 +6483,6 @@ bool hdd_update_config_cfg(struct hdd_context *hdd_ctx)
hdd_err("Couldn't pass on WNI_CFG_AP_LINK_MONITOR_TIMEOUT to CFG");
}
- if (sme_cfg_set_int(mac_handle, WNI_CFG_SINGLE_TID_RC,
- config->bSingleTidRc) == QDF_STATUS_E_FAILURE) {
- status = false;
- hdd_err("Couldn't pass on WNI_CFG_SINGLE_TID_RC to CFG");
- }
-
if (sme_cfg_set_int(mac_handle, WNI_CFG_TELE_BCN_WAKEUP_EN,
config->teleBcnWakeupEn) == QDF_STATUS_E_FAILURE) {
status = false;
@@ -6594,13 +6496,6 @@ bool hdd_update_config_cfg(struct hdd_context *hdd_ctx)
hdd_err("Couldn't pass on WNI_CFG_TELE_BCN_MAX_LI to CFG");
}
- if (sme_cfg_set_int(mac_handle, WNI_CFG_INFRA_STA_KEEP_ALIVE_PERIOD,
- config->infraStaKeepAlivePeriod) ==
- QDF_STATUS_E_FAILURE) {
- status = false;
- hdd_err("Couldn't pass on WNI_CFG_INFRA_STA_KEEP_ALIVE_PERIOD to CFG");
- }
-
if (sme_cfg_set_int(mac_handle, WNI_CFG_FRAGMENTATION_THRESHOLD,
config->FragmentationThreshold) == QDF_STATUS_E_FAILURE) {
status = false;
@@ -6672,12 +6567,6 @@ bool hdd_update_config_cfg(struct hdd_context *hdd_ctx)
hdd_err("Couldn't pass on WNI_CFG_IBSS_ATIM_WIN_SIZE to CFG");
}
- if (sme_cfg_set_int(mac_handle, WNI_CFG_TGT_GTX_USR_CFG,
- config->tgt_gtx_usr_cfg) == QDF_STATUS_E_FAILURE) {
- status = false;
- hdd_err("Couldn't pass on WNI_CFG_TGT_GTX_USR_CFG to CCM");
- }
-
if (sme_cfg_set_int(mac_handle, WNI_CFG_RATE_FOR_TX_MGMT,
config->rate_for_tx_mgmt) ==
QDF_STATUS_E_FAILURE) {
@@ -7205,8 +7094,6 @@ QDF_STATUS hdd_set_sme_config(struct hdd_context *hdd_ctx)
smeConfig->csrConfig.isCoalesingInIBSSAllowed =
hdd_ctx->config->isCoalesingInIBSSAllowed;
- smeConfig->csrConfig.ignore_peer_erp_info =
- pConfig->ignore_peer_erp_info;
/* update SSR config */
sme_update_enable_ssr(mac_handle, hdd_ctx->config->enableSSR);
@@ -7215,8 +7102,6 @@ QDF_STATUS hdd_set_sme_config(struct hdd_context *hdd_ctx)
smeConfig->csrConfig.fEnableDebugLog = hdd_ctx->config->gEnableDebugLog;
- smeConfig->csrConfig.enable5gEBT = hdd_ctx->config->enable5gEBT;
-
smeConfig->csrConfig.enableSelfRecovery =
hdd_ctx->config->enableSelfRecovery;
#ifdef WLAN_FEATURE_ROAM_OFFLOAD
@@ -7250,16 +7135,9 @@ QDF_STATUS hdd_set_sme_config(struct hdd_context *hdd_ctx)
cds_set_multicast_logging(hdd_ctx->config->multicast_host_fw_msgs);
- smeConfig->csrConfig.send_deauth_before_con =
- pConfig->send_deauth_before_con;
-
smeConfig->csrConfig.max_scan_count =
hdd_ctx->config->max_scan_count;
- /* Update 802.11p config */
- smeConfig->csrConfig.enable_dot11p =
- (hdd_ctx->config->dot11p_mode != WLAN_HDD_11P_DISABLED);
-
smeConfig->csrConfig.early_stop_scan_enable =
hdd_ctx->config->early_stop_scan_enable;
smeConfig->csrConfig.early_stop_scan_min_threshold =
@@ -7348,10 +7226,6 @@ QDF_STATUS hdd_set_sme_config(struct hdd_context *hdd_ctx)
hdd_ctx->config->enable_bcast_probe_rsp;
smeConfig->csrConfig.is_fils_enabled =
hdd_ctx->config->is_fils_enabled;
- smeConfig->csrConfig.qcn_ie_support =
- hdd_ctx->config->qcn_ie_support;
- smeConfig->csrConfig.fils_max_chan_guard_time =
- hdd_ctx->config->fils_max_chan_guard_time;
hdd_he_set_sme_config(smeConfig, pConfig);
@@ -7495,9 +7369,16 @@ void hdd_cfg_print_global_config(struct hdd_context *hdd_ctx)
void hdd_get_pmkid_modes(struct hdd_context *hdd_ctx,
struct pmkid_mode_bits *pmkid_modes)
{
- pmkid_modes->fw_okc = (hdd_ctx->config->pmkid_modes &
+ uint32_t cur_pmkid_modes;
+ QDF_STATUS status;
+
+ status = ucfg_mlme_get_pmkid_modes(hdd_ctx->hdd_psoc, &cur_pmkid_modes);
+ if (status != QDF_STATUS_SUCCESS)
+ hdd_err("get pmkid modes fail");
+
+ pmkid_modes->fw_okc = (cur_pmkid_modes &
CFG_PMKID_MODES_OKC) ? 1 : 0;
- pmkid_modes->fw_pmksa_cache = (hdd_ctx->config->pmkid_modes &
+ pmkid_modes->fw_pmksa_cache = (cur_pmkid_modes &
CFG_PMKID_MODES_PMKSA_CACHING) ? 1 : 0;
}
diff --git a/core/hdd/src/wlan_hdd_cfg80211.c b/core/hdd/src/wlan_hdd_cfg80211.c
index 4d76504bd1c1..1f4ac5199463 100644
--- a/core/hdd/src/wlan_hdd_cfg80211.c
+++ b/core/hdd/src/wlan_hdd_cfg80211.c
@@ -120,6 +120,7 @@
#include "wlan_mlme_ucfg_api.h"
#include "wlan_mlme_public_struct.h"
#include "wlan_extscan_ucfg_api.h"
+#include "wlan_mlme_ucfg_api.h"
#define g_mode_rates_size (12)
#define a_mode_rates_size (8)
@@ -5158,7 +5159,7 @@ static int wlan_hdd_save_default_scan_ies(struct hdd_context *hdd_ctx,
uint8_t *ie_data, uint16_t ie_len)
{
struct hdd_scan_info *scan_info = &adapter->scan_info;
- bool add_qcn_ie = hdd_ctx->config->qcn_ie_support;
+ bool add_qcn_ie;
if (!scan_info)
return -EINVAL;
@@ -5169,7 +5170,7 @@ static int wlan_hdd_save_default_scan_ies(struct hdd_context *hdd_ctx,
}
scan_info->default_scan_ies_len = ie_len;
-
+ ucfg_mlme_get_qcn_ie_support(hdd_ctx->hdd_psoc, &add_qcn_ie);
if (add_qcn_ie)
ie_len += (QCN_IE_HDR_LEN + QCN_IE_VERSION_SUBATTR_LEN);
@@ -5486,6 +5487,7 @@ __wlan_hdd_cfg80211_wifi_configuration_set(struct wiphy *wiphy,
uint8_t bmiss_bcnt;
uint16_t latency_level;
mac_handle_t mac_handle;
+ bool b_value;
hdd_enter_dev(dev);
qdf_mem_zero(&request, sizeof(request));
@@ -6024,8 +6026,8 @@ __wlan_hdd_cfg80211_wifi_configuration_set(struct wiphy *wiphy,
}
}
- if (tb[QCA_WLAN_VENDOR_ATTR_CONFIG_RSN_IE] &&
- hdd_ctx->config->force_rsne_override) {
+ ucfg_mlme_get_force_rsne_override(hdd_ctx->hdd_psoc, &b_value);
+ if (tb[QCA_WLAN_VENDOR_ATTR_CONFIG_RSN_IE] && b_value) {
uint8_t force_rsne_override;
force_rsne_override =
diff --git a/core/hdd/src/wlan_hdd_ioctl.c b/core/hdd/src/wlan_hdd_ioctl.c
index b3a4519a6a5e..24dfc820eab3 100644
--- a/core/hdd/src/wlan_hdd_ioctl.c
+++ b/core/hdd/src/wlan_hdd_ioctl.c
@@ -35,7 +35,7 @@
#include
#include "wma.h"
#include "wlan_hdd_napi.h"
-
+#include "wlan_mlme_ucfg_api.h"
#ifdef FEATURE_WLAN_ESE
#include
#include
@@ -4487,6 +4487,8 @@ static int drv_cmd_set_okc_mode(struct hdd_adapter *adapter,
uint32_t okc_mode;
struct pmkid_mode_bits pmkid_modes;
mac_handle_t mac_handle;
+ uint32_t cur_pmkid_modes;
+ QDF_STATUS status;
hdd_get_pmkid_modes(hdd_ctx, &pmkid_modes);
@@ -4507,7 +4509,12 @@ static int drv_cmd_set_okc_mode(struct hdd_adapter *adapter,
value = value + command_len + 1;
/* get the current configured value */
- okc_mode = hdd_ctx->config->pmkid_modes & CFG_PMKID_MODES_OKC;
+ status = ucfg_mlme_get_pmkid_modes(hdd_ctx->hdd_psoc,
+ &cur_pmkid_modes);
+ if (status != QDF_STATUS_SUCCESS)
+ hdd_err("get pmkid modes failed");
+
+ okc_mode = cur_pmkid_modes & CFG_PMKID_MODES_OKC;
/* Convert the value from ascii to integer */
ret = kstrtou32(value, 10, &okc_mode);
@@ -4532,10 +4539,15 @@ static int drv_cmd_set_okc_mode(struct hdd_adapter *adapter,
okc_mode);
if (okc_mode)
- hdd_ctx->config->pmkid_modes |= CFG_PMKID_MODES_OKC;
+ cur_pmkid_modes |= CFG_PMKID_MODES_OKC;
else
- hdd_ctx->config->pmkid_modes &= ~CFG_PMKID_MODES_OKC;
-
+ cur_pmkid_modes &= ~CFG_PMKID_MODES_OKC;
+ status = ucfg_mlme_set_pmkid_modes(hdd_ctx->hdd_psoc,
+ cur_pmkid_modes);
+ if (status != QDF_STATUS_SUCCESS) {
+ ret = -EPERM;
+ hdd_err("set pmkid modes failed");
+ }
exit:
return ret;
}
diff --git a/core/hdd/src/wlan_hdd_main.c b/core/hdd/src/wlan_hdd_main.c
index 23ca718f852e..513aaf4c5d9b 100644
--- a/core/hdd/src/wlan_hdd_main.c
+++ b/core/hdd/src/wlan_hdd_main.c
@@ -9308,6 +9308,7 @@ static int hdd_open_interfaces(struct hdd_context *hdd_ctx, bool rtnl_held)
{
struct hdd_adapter *adapter;
int ret;
+ uint8_t dot11p_mode;
/* open monitor mode adapter if con_mode is monitor mode */
if (con_mode == QDF_GLOBAL_MONITOR_MODE ||
@@ -9325,8 +9326,8 @@ static int hdd_open_interfaces(struct hdd_context *hdd_ctx, bool rtnl_held)
return 0;
}
-
- if (hdd_ctx->config->dot11p_mode == WLAN_HDD_11P_STANDALONE)
+ ucfg_mlme_get_dot11p_mode(hdd_ctx->hdd_psoc, &dot11p_mode);
+ if (dot11p_mode == CFG_11P_STANDALONE)
/* Create only 802.11p interface */
return hdd_open_ocb_interface(hdd_ctx, rtnl_held);
@@ -9348,7 +9349,7 @@ static int hdd_open_interfaces(struct hdd_context *hdd_ctx, bool rtnl_held)
goto err_close_adapters;
/* Open 802.11p Interface */
- if (hdd_ctx->config->dot11p_mode == WLAN_HDD_11P_CONCURRENT) {
+ if (dot11p_mode == CFG_11P_CONCURRENT) {
ret = hdd_open_ocb_interface(hdd_ctx, rtnl_held);
if (ret)
goto err_close_adapters;
@@ -10070,14 +10071,6 @@ static int hdd_pre_enable_configure(struct hdd_context *hdd_ctx)
cdp_register_pause_cb(soc, wlan_hdd_txrx_pause_cb);
/* Register HL netdev flow control callback */
cdp_hl_fc_register(soc, wlan_hdd_txrx_pause_cb);
- /*
- * Set 802.11p config
- * TODO-OCB: This has been temporarily added here to ensure this
- * parameter is set in CSR when we init the channel list. This should
- * be removed once the 5.9 GHz channels are added to the regulatory
- * domain.
- */
- hdd_set_dot11p_config(hdd_ctx);
/*
* Note that the cds_pre_enable() sequence triggers the cfg download.
@@ -10424,6 +10417,7 @@ static int hdd_features_init(struct hdd_context *hdd_ctx)
int ret;
mac_handle_t mac_handle;
struct hdd_config *cfg;
+ bool b_cts2self;
hdd_enter();
@@ -10441,8 +10435,6 @@ static int hdd_features_init(struct hdd_context *hdd_ctx)
/* FW capabilities received, Set the Dot11 mode */
mac_handle = hdd_ctx->mac_handle;
sme_setdef_dot11mode(mac_handle);
- sme_set_prefer_80MHz_over_160MHz(mac_handle,
- hdd_ctx->config->sta_prefer_80MHz_over_160MHz);
sme_set_etsi13_srd_ch_in_master_mode(mac_handle,
cfg->
etsi13_srd_chan_in_master_mode);
@@ -10456,7 +10448,8 @@ static int hdd_features_init(struct hdd_context *hdd_ctx)
sme_cli_set_command(0, WMI_PDEV_PARAM_DATA_STALL_DETECT_ENABLE,
hdd_ctx->config->enable_data_stall_det, PDEV_CMD);
- if (hdd_ctx->config->enable_go_cts2self_for_sta)
+ ucfg_mlme_get_go_cts2self_for_sta(hdd_ctx->hdd_psoc, &b_cts2self);
+ if (b_cts2self)
sme_set_cts2self_for_p2p_go(mac_handle);
if (hdd_set_vc_mode_config(hdd_ctx))
diff --git a/core/hdd/src/wlan_hdd_ocb.c b/core/hdd/src/wlan_hdd_ocb.c
index b0bbf765f23c..9bdd0d88fa7c 100644
--- a/core/hdd/src/wlan_hdd_ocb.c
+++ b/core/hdd/src/wlan_hdd_ocb.c
@@ -50,21 +50,6 @@
/* Maximum time(ms) to wait for OCB operations */
#define WLAN_WAIT_TIME_OCB_CMD 1500
-/**
- * hdd_set_dot11p_config() - Set 802.11p config flag
- * @hdd_ctx: HDD Context pointer
- *
- * TODO-OCB: This has been temporarily added to ensure this parameter
- * is set in CSR when we init the channel list. This should be removed
- * once the 5.9 GHz channels are added to the regulatory domain.
- */
-void hdd_set_dot11p_config(struct hdd_context *hdd_ctx)
-{
- sme_set_dot11p_config(hdd_ctx->mac_handle,
- hdd_ctx->config->dot11p_mode !=
- WLAN_HDD_11P_DISABLED);
-}
-
/**
* dot11p_validate_qos_params() - Check if QoS parameters are valid
* @qos_params: Array of QoS parameters
diff --git a/core/hdd/src/wlan_hdd_ocb.h b/core/hdd/src/wlan_hdd_ocb.h
index 21bb3bee066e..2e13a535d634 100644
--- a/core/hdd/src/wlan_hdd_ocb.h
+++ b/core/hdd/src/wlan_hdd_ocb.h
@@ -250,8 +250,6 @@ int iw_set_dot11p_channel_sched(struct net_device *dev,
#endif
#ifdef WLAN_FEATURE_DSRC
-void hdd_set_dot11p_config(struct hdd_context *hdd_ctx);
-
int wlan_hdd_cfg80211_ocb_set_config(struct wiphy *wiphy,
struct wireless_dev *wdev,
const void *data,
@@ -296,10 +294,6 @@ void wlan_hdd_dcc_register_for_dcc_stats_event(struct hdd_context *hdd_ctx);
void wlan_hdd_dcc_stats_event(void *context_ptr, void *response_ptr);
#else
-static inline void hdd_set_dot11p_config(struct hdd_context *hdd_ctx)
-{
-}
-
static inline int wlan_hdd_cfg80211_ocb_set_config(struct wiphy *wiphy,
struct wireless_dev *wdev,
const void *data,
diff --git a/core/hdd/src/wlan_hdd_power.c b/core/hdd/src/wlan_hdd_power.c
index c30021470f6e..db1d00013f2e 100644
--- a/core/hdd/src/wlan_hdd_power.c
+++ b/core/hdd/src/wlan_hdd_power.c
@@ -78,6 +78,8 @@
#include "wlan_ipa_ucfg_api.h"
#include
#include "wlan_p2p_ucfg_api.h"
+#include "wlan_mlme_ucfg_api.h"
+
/* Preprocessor definitions and constants */
#ifdef QCA_WIFI_NAPIER_EMULATION
#define HDD_SSR_BRING_UP_TIME 3000000
@@ -680,7 +682,8 @@ static int hdd_set_grat_arp_keepalive(struct hdd_adapter *adapter)
sizeof(req.destIpv4Addr));
qdf_copy_macaddr(&req.bssid, &sta_ctx->conn_info.bssId);
- req.timePeriod = hdd_ctx->config->infraStaKeepAlivePeriod;
+ ucfg_mlme_get_sta_keep_alive_period(hdd_ctx->hdd_psoc,
+ &req.timePeriod);
req.sessionId = adapter->session_id;
hdd_debug("Setting gratuitous ARP keepalive; ipv4_addr:%u.%u.%u.%u",
diff --git a/core/hdd/src/wlan_hdd_wext.c b/core/hdd/src/wlan_hdd_wext.c
index 562ea1490c3c..017b2f0b22cd 100644
--- a/core/hdd/src/wlan_hdd_wext.c
+++ b/core/hdd/src/wlan_hdd_wext.c
@@ -99,7 +99,8 @@
#include "wlan_hdd_packet_filter_api.h"
#include "wlan_cp_stats_mc_ucfg_api.h"
#include "wlan_mlme_ucfg_api.h"
-#include "wlan_mlme_public_struct.h"
+#include "cfg_mlme_sta.h"
+#include "cfg_ucfg_api.h"
#define HDD_FINISH_ULA_TIME_OUT 800
#define HDD_SET_MCBC_FILTERS_TO_FW 1
@@ -8025,10 +8026,10 @@ static int __iw_set_keepalive_params(struct net_device *dev,
return -EINVAL;
}
- if (request->timePeriod > WNI_CFG_INFRA_STA_KEEP_ALIVE_PERIOD_STAMAX) {
+ if (request->timePeriod > cfg_max(CFG_INFRA_STA_KEEP_ALIVE_PERIOD)) {
hdd_err("Value of timePeriod %d exceed Max limit %d",
request->timePeriod,
- WNI_CFG_INFRA_STA_KEEP_ALIVE_PERIOD_STAMAX);
+ cfg_max(CFG_INFRA_STA_KEEP_ALIVE_PERIOD));
return -EINVAL;
}
diff --git a/core/mac/inc/ani_global.h b/core/mac/inc/ani_global.h
index 8623a41241f4..957b3580a6d0 100644
--- a/core/mac/inc/ani_global.h
+++ b/core/mac/inc/ani_global.h
@@ -867,7 +867,6 @@ typedef struct sAniSirGlobal {
uint8_t beacon_offload;
bool pmf_offload;
bool is_fils_roaming_supported;
- bool enable5gEBT;
uint8_t f_prefer_non_dfs_on_radar;
uint32_t fEnableDebugLog;
uint32_t f_sta_miracast_mcc_rest_time_val;
@@ -879,8 +878,6 @@ typedef struct sAniSirGlobal {
struct vdev_type_nss vdev_type_nss_5g;
uint16_t mgmtSeqNum;
- /* 802.11p enable */
- bool enable_dot11p;
/* DBS capability based on INI and FW capability */
uint8_t hw_dbs_capable;
uint32_t sta_sap_scc_on_dfs_chan;
@@ -898,7 +895,6 @@ typedef struct sAniSirGlobal {
uint8_t user_configured_nss;
bool snr_monitor_enabled;
bool ignore_assoc_disallowed;
- bool sta_prefer_80MHz_over_160MHz;
int8_t first_scan_bucket_threshold;
uint32_t peer_rssi;
uint32_t peer_txrate;
diff --git a/core/mac/inc/wni_cfg.h b/core/mac/inc/wni_cfg.h
index e646921634ec..72e807f50f8d 100644
--- a/core/mac/inc/wni_cfg.h
+++ b/core/mac/inc/wni_cfg.h
@@ -74,10 +74,8 @@ enum {
WNI_CFG_MAX_TX_POWER_2_4,
WNI_CFG_MAX_TX_POWER_5,
WNI_CFG_CURRENT_TX_POWER_LEVEL,
- WNI_CFG_NEW_BSS_FOUND_IND,
WNI_CFG_COUNTRY_CODE,
WNI_CFG_11H_ENABLED,
- WNI_CFG_WT_CNF_TIMEOUT,
WNI_CFG_OLBC_DETECT_TIMEOUT,
WNI_CFG_PROTECTION_ENABLED,
WNI_CFG_11G_PROTECTION_ALWAYS,
@@ -172,10 +170,8 @@ enum {
WNI_CFG_WPS_PIMARY_DEVICE_OUI,
WNI_CFG_WPS_DEVICE_SUB_CATEGORY,
WNI_CFG_WPS_DEVICE_PASSWORD_ID,
- WNI_CFG_SINGLE_TID_RC,
WNI_CFG_TELE_BCN_WAKEUP_EN,
WNI_CFG_TELE_BCN_MAX_LI,
- WNI_CFG_INFRA_STA_KEEP_ALIVE_PERIOD,
WNI_CFG_ASSOC_STA_LIMIT,
WNI_CFG_ENABLE_LTE_COEX,
WNI_CFG_AP_KEEP_ALIVE_TIMEOUT,
@@ -186,12 +182,10 @@ enum {
WNI_CFG_PMF_SA_QUERY_MAX_RETRIES,
WNI_CFG_PMF_SA_QUERY_RETRY_INTERVAL,
WNI_CFG_RMC_ACTION_PERIOD_FREQUENCY,
- WNI_CFG_CURRENT_RSSI,
WNI_CFG_RTT3_ENABLE,
WNI_CFG_IBSS_ATIM_WIN_SIZE,
WNI_CFG_DFS_MASTER_ENABLED,
WNI_CFG_VHT_ENABLE_TXBF_20MHZ,
- WNI_CFG_TGT_GTX_USR_CFG,
WNI_CFG_MAX_HT_MCS_TX_DATA,
WNI_CFG_DISABLE_ABG_RATE_FOR_TX_DATA,
WNI_CFG_RATE_FOR_TX_MGMT,
@@ -640,20 +634,10 @@ enum {
#define WNI_CFG_CURRENT_TX_POWER_LEVEL_STAMAX 128
#define WNI_CFG_CURRENT_TX_POWER_LEVEL_STADEF 27
-
-
-#define WNI_CFG_NEW_BSS_FOUND_IND_STAMIN 0
-#define WNI_CFG_NEW_BSS_FOUND_IND_STAMAX 1
-#define WNI_CFG_NEW_BSS_FOUND_IND_STADEF 0
-
#define WNI_CFG_11H_ENABLED_STAMIN 0
#define WNI_CFG_11H_ENABLED_STAMAX 1
#define WNI_CFG_11H_ENABLED_STADEF 1
-#define WNI_CFG_WT_CNF_TIMEOUT_STAMIN 10
-#define WNI_CFG_WT_CNF_TIMEOUT_STAMAX 3000
-#define WNI_CFG_WT_CNF_TIMEOUT_STADEF 1000
-
#define WNI_CFG_OLBC_DETECT_TIMEOUT_STAMIN 1000
#define WNI_CFG_OLBC_DETECT_TIMEOUT_STAMAX 30000
#define WNI_CFG_OLBC_DETECT_TIMEOUT_STADEF 10000
@@ -1102,10 +1086,6 @@ enum {
#define WNI_CFG_WPS_DEVICE_PASSWORD_ID_STAMAX 4294967295
#define WNI_CFG_WPS_DEVICE_PASSWORD_ID_STADEF 0
-#define WNI_CFG_SINGLE_TID_RC_STAMIN 0
-#define WNI_CFG_SINGLE_TID_RC_STAMAX 1
-#define WNI_CFG_SINGLE_TID_RC_STADEF 1
-
#define WNI_CFG_TELE_BCN_WAKEUP_EN_STAMIN 0
#define WNI_CFG_TELE_BCN_WAKEUP_EN_STAMAX 1
#define WNI_CFG_TELE_BCN_WAKEUP_EN_STADEF 0
@@ -1114,10 +1094,6 @@ enum {
#define WNI_CFG_TELE_BCN_MAX_LI_STAMAX 7
#define WNI_CFG_TELE_BCN_MAX_LI_STADEF 5
-#define WNI_CFG_INFRA_STA_KEEP_ALIVE_PERIOD_STAMIN 0
-#define WNI_CFG_INFRA_STA_KEEP_ALIVE_PERIOD_STAMAX 1000
-#define WNI_CFG_INFRA_STA_KEEP_ALIVE_PERIOD_STADEF 0
-
#define WNI_CFG_ASSOC_STA_LIMIT_STAMIN 1
#define WNI_CFG_ASSOC_STA_LIMIT_STAMAX 32
#define WNI_CFG_ASSOC_STA_LIMIT_STADEF 10
@@ -1158,10 +1134,6 @@ enum {
#define WNI_CFG_RMC_ACTION_PERIOD_FREQUENCY_STAMAX 1000
#define WNI_CFG_RMC_ACTION_PERIOD_FREQUENCY_STADEF 300
-#define WNI_CFG_CURRENT_RSSI_STAMIN 0
-#define WNI_CFG_CURRENT_RSSI_STAMAX 127
-#define WNI_CFG_CURRENT_RSSI_STADEF 0
-
#define WNI_CFG_RTT3_ENABLE_STAMIN 0
#define WNI_CFG_RTT3_ENABLE_STAMAX 1
#define WNI_CFG_RTT3_ENABLE_STADEF 1
@@ -1178,10 +1150,6 @@ enum {
#define WNI_CFG_VHT_ENABLE_TXBF_20MHZ_STAMAX 1
#define WNI_CFG_VHT_ENABLE_TXBF_20MHZ_STADEF 0
-#define WNI_CFG_TGT_GTX_USR_CFG_STAMIN 0
-#define WNI_CFG_TGT_GTX_USR_CFG_STAMAX 32
-#define WNI_CFG_TGT_GTX_USR_CFG_STADEF 32
-
#define WNI_CFG_MAX_HT_MCS_TX_DATA_STAMIN 0x0
#define WNI_CFG_MAX_HT_MCS_TX_DATA_STAMAX 0x17f
#define WNI_CFG_MAX_HT_MCS_TX_DATA_STADEF 0x0
diff --git a/core/mac/src/cfg/cfgUtil/cfg.txt b/core/mac/src/cfg/cfgUtil/cfg.txt
index 039855704469..e881c45f8c08 100644
--- a/core/mac/src/cfg/cfgUtil/cfg.txt
+++ b/core/mac/src/cfg/cfgUtil/cfg.txt
@@ -1112,18 +1112,6 @@ V RW NP
NONE
0 128 27
-*
-* Parameter to indicate or not new BSS found
-*
-WNI_CFG_NEW_BSS_FOUND_IND I 4 9
-V RW NP
-NONE
-0 1 0
-V RW NP
-NONE
-0 1 0
-
-
*
* Qualcomm Prop Rates are disabled by default
*
@@ -1172,19 +1160,6 @@ V RW NP RESTART
NONE
0 1 1
-*
-* Wait for CNF Timeout. CNF include (RE)ASSOC, DISASSOC, AUTH, DEAUTH,
-* DUMMY packet
-*
-
-WNI_CFG_WT_CNF_TIMEOUT I 4 12
-V RW NP
-NONE
-10 3000 1000
-V RW NP
-NONE
-10 3000 1000
-
*
* Proximity, set it for very short distances
* Proxmity setting is applied via halPhySetNwDensity()
@@ -3662,17 +3637,6 @@ HAL
0 0xFF 7
*
-* Infra STA mode Keep alive period (in secs) for
-* sending keep alive (Qos)Null frames to the AP.
-* 0 = disabled. Recommended values is 30 secs
-*
-WNI_CFG_INFRA_STA_KEEP_ALIVE_PERIOD I 4 7
-V RW NP
-HAL
-0 1000 0
-V RW NP
-HAL
-0 1000 0
* Limit on number of associated stations
* (applies to peer stations in IBSS, SoftAP, BT-AMP AP, & P2P-GO modes)
@@ -3868,16 +3832,6 @@ HAL
*
*
-* Current RSSI value (of connected AP)
-*
-WNI_CFG_CURRENT_RSSI I 4 7
-V RW NP
-NONE
-0 127 0
-V RW NP
-NONE
-0 127 0
-
* RTT3 Bit Value
*
WNI_CFG_RTT3_ENABLE I 1 1
diff --git a/core/mac/src/cfg/cfg_param_name.c b/core/mac/src/cfg/cfg_param_name.c
index 033639ac2a77..be8b174287e8 100644
--- a/core/mac/src/cfg/cfg_param_name.c
+++ b/core/mac/src/cfg/cfg_param_name.c
@@ -89,10 +89,8 @@ const char *cfg_get_string(uint16_t cfg_id)
CASE_RETURN_STRING(WNI_CFG_MAX_TX_POWER_2_4);
CASE_RETURN_STRING(WNI_CFG_MAX_TX_POWER_5);
CASE_RETURN_STRING(WNI_CFG_CURRENT_TX_POWER_LEVEL);
- CASE_RETURN_STRING(WNI_CFG_NEW_BSS_FOUND_IND);
CASE_RETURN_STRING(WNI_CFG_COUNTRY_CODE);
CASE_RETURN_STRING(WNI_CFG_11H_ENABLED);
- CASE_RETURN_STRING(WNI_CFG_WT_CNF_TIMEOUT);
CASE_RETURN_STRING(WNI_CFG_OLBC_DETECT_TIMEOUT);
CASE_RETURN_STRING(WNI_CFG_PROTECTION_ENABLED);
CASE_RETURN_STRING(WNI_CFG_11G_PROTECTION_ALWAYS);
@@ -186,10 +184,8 @@ const char *cfg_get_string(uint16_t cfg_id)
CASE_RETURN_STRING(WNI_CFG_WPS_PIMARY_DEVICE_OUI);
CASE_RETURN_STRING(WNI_CFG_WPS_DEVICE_SUB_CATEGORY);
CASE_RETURN_STRING(WNI_CFG_WPS_DEVICE_PASSWORD_ID);
- CASE_RETURN_STRING(WNI_CFG_SINGLE_TID_RC);
CASE_RETURN_STRING(WNI_CFG_TELE_BCN_WAKEUP_EN);
CASE_RETURN_STRING(WNI_CFG_TELE_BCN_MAX_LI);
- CASE_RETURN_STRING(WNI_CFG_INFRA_STA_KEEP_ALIVE_PERIOD);
CASE_RETURN_STRING(WNI_CFG_ASSOC_STA_LIMIT);
CASE_RETURN_STRING(WNI_CFG_ENABLE_LTE_COEX);
CASE_RETURN_STRING(WNI_CFG_AP_KEEP_ALIVE_TIMEOUT);
@@ -200,12 +196,10 @@ const char *cfg_get_string(uint16_t cfg_id)
CASE_RETURN_STRING(WNI_CFG_PMF_SA_QUERY_MAX_RETRIES);
CASE_RETURN_STRING(WNI_CFG_PMF_SA_QUERY_RETRY_INTERVAL);
CASE_RETURN_STRING(WNI_CFG_RMC_ACTION_PERIOD_FREQUENCY);
- CASE_RETURN_STRING(WNI_CFG_CURRENT_RSSI);
CASE_RETURN_STRING(WNI_CFG_RTT3_ENABLE);
CASE_RETURN_STRING(WNI_CFG_IBSS_ATIM_WIN_SIZE);
CASE_RETURN_STRING(WNI_CFG_DFS_MASTER_ENABLED);
CASE_RETURN_STRING(WNI_CFG_VHT_ENABLE_TXBF_20MHZ);
- CASE_RETURN_STRING(WNI_CFG_TGT_GTX_USR_CFG);
CASE_RETURN_STRING(WNI_CFG_MAX_HT_MCS_TX_DATA);
CASE_RETURN_STRING(WNI_CFG_DISABLE_ABG_RATE_FOR_TX_DATA);
CASE_RETURN_STRING(WNI_CFG_RATE_FOR_TX_MGMT);
diff --git a/core/mac/src/cfg/cfg_proc_msg.c b/core/mac/src/cfg/cfg_proc_msg.c
index efbdea0932d5..6e35b65bf6b3 100644
--- a/core/mac/src/cfg/cfg_proc_msg.c
+++ b/core/mac/src/cfg/cfg_proc_msg.c
@@ -258,11 +258,6 @@ cgstatic cfg_static[CFG_PARAM_MAX_NUM] = {
WNI_CFG_CURRENT_TX_POWER_LEVEL_STAMIN,
WNI_CFG_CURRENT_TX_POWER_LEVEL_STAMAX,
WNI_CFG_CURRENT_TX_POWER_LEVEL_STADEF},
- {WNI_CFG_NEW_BSS_FOUND_IND,
- CFG_CTL_VALID | CFG_CTL_RE | CFG_CTL_WE | CFG_CTL_INT,
- WNI_CFG_NEW_BSS_FOUND_IND_STAMIN,
- WNI_CFG_NEW_BSS_FOUND_IND_STAMAX,
- WNI_CFG_NEW_BSS_FOUND_IND_STADEF},
{WNI_CFG_COUNTRY_CODE,
CFG_CTL_VALID | CFG_CTL_RE | CFG_CTL_WE | CFG_CTL_NTF_SCH,
0, 0, 0},
@@ -272,11 +267,6 @@ cgstatic cfg_static[CFG_PARAM_MAX_NUM] = {
WNI_CFG_11H_ENABLED_STAMIN,
WNI_CFG_11H_ENABLED_STAMAX,
WNI_CFG_11H_ENABLED_STADEF},
- {WNI_CFG_WT_CNF_TIMEOUT,
- CFG_CTL_VALID | CFG_CTL_RE | CFG_CTL_WE | CFG_CTL_INT,
- WNI_CFG_WT_CNF_TIMEOUT_STAMIN,
- WNI_CFG_WT_CNF_TIMEOUT_STAMAX,
- WNI_CFG_WT_CNF_TIMEOUT_STADEF},
{WNI_CFG_OLBC_DETECT_TIMEOUT,
CFG_CTL_VALID | CFG_CTL_RE | CFG_CTL_WE | CFG_CTL_INT,
WNI_CFG_OLBC_DETECT_TIMEOUT_STAMIN,
@@ -770,11 +760,6 @@ cgstatic cfg_static[CFG_PARAM_MAX_NUM] = {
WNI_CFG_WPS_DEVICE_PASSWORD_ID_STAMIN,
4294967295u,
WNI_CFG_WPS_DEVICE_PASSWORD_ID_STADEF},
- {WNI_CFG_SINGLE_TID_RC,
- CFG_CTL_VALID | CFG_CTL_RE | CFG_CTL_WE | CFG_CTL_INT,
- WNI_CFG_SINGLE_TID_RC_STAMIN,
- WNI_CFG_SINGLE_TID_RC_STAMAX,
- WNI_CFG_SINGLE_TID_RC_STADEF},
{WNI_CFG_TELE_BCN_WAKEUP_EN,
CFG_CTL_VALID | CFG_CTL_RE | CFG_CTL_WE | CFG_CTL_INT,
WNI_CFG_TELE_BCN_WAKEUP_EN_STAMIN,
@@ -785,11 +770,6 @@ cgstatic cfg_static[CFG_PARAM_MAX_NUM] = {
WNI_CFG_TELE_BCN_MAX_LI_STAMIN,
WNI_CFG_TELE_BCN_MAX_LI_STAMAX,
WNI_CFG_TELE_BCN_MAX_LI_STADEF},
- {WNI_CFG_INFRA_STA_KEEP_ALIVE_PERIOD,
- CFG_CTL_VALID | CFG_CTL_RE | CFG_CTL_WE | CFG_CTL_INT,
- WNI_CFG_INFRA_STA_KEEP_ALIVE_PERIOD_STAMIN,
- WNI_CFG_INFRA_STA_KEEP_ALIVE_PERIOD_STAMAX,
- WNI_CFG_INFRA_STA_KEEP_ALIVE_PERIOD_STADEF},
{WNI_CFG_ASSOC_STA_LIMIT,
CFG_CTL_VALID | CFG_CTL_RE | CFG_CTL_WE | CFG_CTL_INT |
CFG_CTL_NTF_LIM,
@@ -843,11 +823,6 @@ cgstatic cfg_static[CFG_PARAM_MAX_NUM] = {
WNI_CFG_RMC_ACTION_PERIOD_FREQUENCY_STAMIN,
WNI_CFG_RMC_ACTION_PERIOD_FREQUENCY_STAMAX,
WNI_CFG_RMC_ACTION_PERIOD_FREQUENCY_STADEF},
- {WNI_CFG_CURRENT_RSSI,
- CFG_CTL_VALID | CFG_CTL_RE | CFG_CTL_WE | CFG_CTL_INT,
- WNI_CFG_CURRENT_RSSI_STAMIN,
- WNI_CFG_CURRENT_RSSI_STAMAX,
- WNI_CFG_CURRENT_RSSI_STADEF},
{WNI_CFG_RTT3_ENABLE,
CFG_CTL_VALID | CFG_CTL_RE | CFG_CTL_WE | CFG_CTL_INT,
WNI_CFG_RTT3_ENABLE_STAMIN,
@@ -868,11 +843,6 @@ cgstatic cfg_static[CFG_PARAM_MAX_NUM] = {
WNI_CFG_VHT_ENABLE_TXBF_20MHZ_STAMIN,
WNI_CFG_VHT_ENABLE_TXBF_20MHZ_STAMAX,
WNI_CFG_VHT_ENABLE_TXBF_20MHZ_STADEF},
- {WNI_CFG_TGT_GTX_USR_CFG,
- CFG_CTL_VALID | CFG_CTL_RE | CFG_CTL_WE | CFG_CTL_INT,
- WNI_CFG_TGT_GTX_USR_CFG_STAMIN,
- WNI_CFG_TGT_GTX_USR_CFG_STAMAX,
- WNI_CFG_TGT_GTX_USR_CFG_STADEF},
{WNI_CFG_MAX_HT_MCS_TX_DATA,
CFG_CTL_VALID | CFG_CTL_RE | CFG_CTL_WE | CFG_CTL_INT,
WNI_CFG_MAX_HT_MCS_TX_DATA_STAMIN,
diff --git a/core/mac/src/pe/lim/lim_ft.c b/core/mac/src/pe/lim/lim_ft.c
index 55c7070fd561..24c1e5884b19 100644
--- a/core/mac/src/pe/lim/lim_ft.c
+++ b/core/mac/src/pe/lim/lim_ft.c
@@ -743,7 +743,6 @@ bool lim_process_ft_update_key(tpAniSirGlobal pMac, uint32_t *pMsgBuf)
{
tAddBssParams *pAddBssParams;
tSirFTUpdateKeyInfo *pKeyInfo;
- uint32_t val = 0;
tpPESession psessionEntry;
uint8_t sessionId;
@@ -806,12 +805,9 @@ bool lim_process_ft_update_key(tpAniSirGlobal pMac, uint32_t *pMsgBuf)
qdf_mem_copy((uint8_t *) &pAddBssParams->extSetStaKeyParam.key,
(uint8_t *) &pKeyInfo->keyMaterial.key,
sizeof(tSirKeys));
- if (QDF_STATUS_SUCCESS !=
- wlan_cfg_get_int(pMac, WNI_CFG_SINGLE_TID_RC, &val)) {
- pe_warn("Unable to read WNI_CFG_SINGLE_TID_RC");
- }
- pAddBssParams->extSetStaKeyParam.singleTidRc = val;
+ pAddBssParams->extSetStaKeyParam.singleTidRc =
+ (uint8_t)pMac->mlme_cfg->sta.single_tid;
pe_debug("Key valid: %d keyLength: %d",
pAddBssParams->extSetStaKeyParamValid,
pAddBssParams->extSetStaKeyParam.key[0].keyLength);
diff --git a/core/mac/src/pe/lim/lim_link_monitoring_algo.c b/core/mac/src/pe/lim/lim_link_monitoring_algo.c
index de1ac660ec83..de62a062cdb1 100644
--- a/core/mac/src/pe/lim/lim_link_monitoring_algo.c
+++ b/core/mac/src/pe/lim/lim_link_monitoring_algo.c
@@ -399,12 +399,12 @@ lim_tear_down_link_with_ap(tpAniSirGlobal pMac, uint8_t sessionId,
pStaDs->staAddr, sizeof(tSirMacAddr));
/*
- * if send_deauth_before_con is enabled and reasoncode is
+ * if deauth_before_connection is enabled and reasoncode is
* Beacon Missed Store the MAC of AP in the flip flop
* buffer. This MAC will be used to send Deauth before
* connection, if we connect to same AP after HB failure.
*/
- if (pMac->roam.configParam.send_deauth_before_con &&
+ if (pMac->mlme_cfg->sta.deauth_before_connection &&
eSIR_BEACON_MISSED == reasonCode) {
int apCount = pMac->lim.gLimHeartBeatApMacIndex;
diff --git a/core/mac/src/pe/lim/lim_prop_exts_utils.c b/core/mac/src/pe/lim/lim_prop_exts_utils.c
index d1cd07f4fda0..3656891d36d2 100644
--- a/core/mac/src/pe/lim/lim_prop_exts_utils.c
+++ b/core/mac/src/pe/lim/lim_prop_exts_utils.c
@@ -303,7 +303,7 @@ lim_extract_ap_capability(tpAniSirGlobal mac_ctx, uint8_t *p_ie,
* in 2x2 80MHz mode instead of connecting in 160MHz mode.
*/
if ((vht_ch_wd > WNI_CFG_VHT_CHANNEL_WIDTH_80MHZ) &&
- mac_ctx->sta_prefer_80MHz_over_160MHz) {
+ mac_ctx->mlme_cfg->sta.sta_prefer_80mhz_over_160mhz) {
if (!(IS_VHT_NSS_1x1(beacon_struct->VHTCaps.txMCSMap))
&&
(!IS_VHT_NSS_1x1(beacon_struct->VHTCaps.rxMCSMap)))
diff --git a/core/mac/src/pe/lim/lim_security_utils.c b/core/mac/src/pe/lim/lim_security_utils.c
index 3d5dc42539ab..e0c8bb3dfd08 100644
--- a/core/mac/src/pe/lim/lim_security_utils.c
+++ b/core/mac/src/pe/lim/lim_security_utils.c
@@ -784,7 +784,6 @@ void lim_send_set_bss_key_req(tpAniSirGlobal pMac,
tpSetBssKeyParams pSetBssKeyParams = NULL;
tLimMlmSetKeysCnf mlmSetKeysCnf;
QDF_STATUS retCode;
- uint32_t val = 0;
if (pMlmSetKeysReq->numKeys > SIR_MAC_MAX_NUM_OF_DEFAULT_KEYS) {
pe_debug("numKeys = %d is more than SIR_MAC_MAX_NUM_OF_DEFAULT_KEYS",
@@ -809,11 +808,8 @@ void lim_send_set_bss_key_req(tpAniSirGlobal pMac,
pSetBssKeyParams->bssIdx = psessionEntry->bssIdx;
pSetBssKeyParams->encType = pMlmSetKeysReq->edType;
- if (QDF_STATUS_SUCCESS != wlan_cfg_get_int(pMac, WNI_CFG_SINGLE_TID_RC, &val))
- pe_warn("Unable to read WNI_CFG_SINGLE_TID_RC");
-
- pSetBssKeyParams->singleTidRc = (uint8_t) val;
-
+ pSetBssKeyParams->singleTidRc =
+ (uint8_t)(pMac->mlme_cfg->sta.single_tid);
/* Update PE session Id */
pSetBssKeyParams->sessionId = psessionEntry->peSessionId;
@@ -892,7 +888,6 @@ void lim_send_set_sta_key_req(tpAniSirGlobal pMac,
tpSetStaKeyParams pSetStaKeyParams = NULL;
tLimMlmSetKeysCnf mlmSetKeysCnf;
QDF_STATUS retCode;
- uint32_t val = 0;
/* Package WMA_SET_STAKEY_REQ message parameters */
pSetStaKeyParams = qdf_mem_malloc(sizeof(tSetStaKeyParams));
@@ -905,11 +900,8 @@ void lim_send_set_sta_key_req(tpAniSirGlobal pMac,
pSetStaKeyParams->staIdx = staIdx;
pSetStaKeyParams->encType = pMlmSetKeysReq->edType;
- if (QDF_STATUS_SUCCESS != wlan_cfg_get_int(pMac, WNI_CFG_SINGLE_TID_RC, &val))
- pe_warn("Unable to read WNI_CFG_SINGLE_TID_RC");
-
- pSetStaKeyParams->singleTidRc = (uint8_t) val;
-
+ pSetStaKeyParams->singleTidRc =
+ (uint8_t)(pMac->mlme_cfg->sta.single_tid);
/* Update PE session ID */
pSetStaKeyParams->sessionId = sessionEntry->peSessionId;
diff --git a/core/mac/src/pe/lim/lim_send_management_frames.c b/core/mac/src/pe/lim/lim_send_management_frames.c
index 5164db91dfeb..cbcecb228e6a 100644
--- a/core/mac/src/pe/lim/lim_send_management_frames.c
+++ b/core/mac/src/pe/lim/lim_send_management_frames.c
@@ -375,7 +375,7 @@ lim_send_probe_req_mgmt_frame(tpAniSirGlobal mac_ctx,
additional_ie, addn_ielen);
}
/* Add qcn_ie only if qcn ie is not present in additional_ie */
- if (mac_ctx->roam.configParam.qcn_ie_support && !qcn_ie)
+ if (mac_ctx->mlme_cfg->sta.qcn_ie_support && !qcn_ie)
populate_dot11f_qcn_ie(&pr.QCN_IE);
/*
@@ -1879,7 +1879,7 @@ lim_send_assoc_req_mgmt_frame(tpAniSirGlobal mac_ctx,
populate_dot11f_ext_cap(mac_ctx, vht_enabled,
&frm->ExtCap, pe_session);
- if (mac_ctx->roam.configParam.qcn_ie_support)
+ if (mac_ctx->mlme_cfg->sta.qcn_ie_support)
populate_dot11f_qcn_ie(&frm->QCN_IE);
if (lim_is_session_he_capable(pe_session)) {
diff --git a/core/mac/src/pe/lim/lim_timer_utils.c b/core/mac/src/pe/lim/lim_timer_utils.c
index 4c5dadcd2c9e..0abb847ee97f 100644
--- a/core/mac/src/pe/lim/lim_timer_utils.c
+++ b/core/mac/src/pe/lim/lim_timer_utils.c
@@ -232,12 +232,7 @@ uint32_t lim_create_timers(tpAniSirGlobal pMac)
if (false == lim_create_non_ap_timers(pMac))
goto err_timer;
- /* Create all CNF_WAIT Timers upfront */
- if (wlan_cfg_get_int(pMac, WNI_CFG_WT_CNF_TIMEOUT, &cfgValue)
- != QDF_STATUS_SUCCESS) {
- pe_err("could not retrieve CNF timeout value");
- }
-
+ cfgValue = pMac->mlme_cfg->sta.wait_cnf_timeout;
cfgValue = SYS_MS_TO_TICKS(cfgValue);
for (i = 0; i < (pMac->lim.maxStation + 1); i++) {
if (tx_timer_create(pMac,
@@ -893,15 +888,7 @@ lim_deactivate_and_change_per_sta_id_timer(tpAniSirGlobal pMac, uint32_t timerId
pe_err("unable to deactivate CNF wait timer");
}
/* Change timer to reactivate it in future */
-
- if (wlan_cfg_get_int(pMac, WNI_CFG_WT_CNF_TIMEOUT,
- &val) != QDF_STATUS_SUCCESS) {
- /**
- * Could not get cnf timeout value
- * from CFG. Log error.
- */
- pe_err("could not retrieve cnf timeout value");
- }
+ val = pMac->mlme_cfg->sta.wait_cnf_timeout;
val = SYS_MS_TO_TICKS(val);
if (tx_timer_change
diff --git a/core/mac/src/pe/sch/sch_beacon_process.c b/core/mac/src/pe/sch/sch_beacon_process.c
index 5dd020b90e3d..7a4e4f122ea9 100644
--- a/core/mac/src/pe/sch/sch_beacon_process.c
+++ b/core/mac/src/pe/sch/sch_beacon_process.c
@@ -114,13 +114,13 @@ ap_beacon_process_24_ghz(tpAniSirGlobal mac_ctx, uint8_t *rx_pkt_info,
if (bcn_struct->channelNumber != session->currentOperChannel)
return;
- tmp_exp = (!bcn_struct->erpPresent
- && !bcn_struct->HTInfo.present)
+ tmp_exp = (!bcn_struct->erpPresent &&
+ !bcn_struct->HTInfo.present) ||
/* if erp not present then 11B AP overlapping */
- || (!mac_ctx->roam.configParam.ignore_peer_erp_info &&
- bcn_struct->erpPresent &&
- (bcn_struct->erpIEInfo.useProtection
- || bcn_struct->erpIEInfo.nonErpPresent));
+ (!mac_ctx->mlme_cfg->sta.ignore_peer_erp_info &&
+ bcn_struct->erpPresent &&
+ (bcn_struct->erpIEInfo.useProtection ||
+ bcn_struct->erpIEInfo.nonErpPresent));
if (!tmp_exp)
return;
#ifdef FEATURE_WLAN_ESE
@@ -143,12 +143,12 @@ ap_beacon_process_24_ghz(tpAniSirGlobal mac_ctx, uint8_t *rx_pkt_info,
if (bcn_struct->channelNumber != session->currentOperChannel)
return;
- tmp_exp = (!bcn_struct->erpPresent && !bcn_struct->HTInfo.present)
+ tmp_exp = (!bcn_struct->erpPresent && !bcn_struct->HTInfo.present) ||
/* if erp not present then 11B AP overlapping */
- || (!mac_ctx->roam.configParam.ignore_peer_erp_info &&
- bcn_struct->erpPresent &&
- (bcn_struct->erpIEInfo.useProtection
- || bcn_struct->erpIEInfo.nonErpPresent));
+ (!mac_ctx->mlme_cfg->sta.ignore_peer_erp_info &&
+ bcn_struct->erpPresent &&
+ (bcn_struct->erpIEInfo.useProtection ||
+ bcn_struct->erpIEInfo.nonErpPresent));
if (tmp_exp) {
#ifdef FEATURE_WLAN_ESE
if (session->isESEconnection) {
@@ -1340,7 +1340,7 @@ QDF_STATUS lim_obss_generate_detection_config(tpAniSirGlobal mac_ctx,
}
/* INI related settings */
- if (mac_ctx->roam.configParam.ignore_peer_erp_info)
+ if (mac_ctx->mlme_cfg->sta.ignore_peer_erp_info)
cfg->obss_11b_sta_detect_mode =
OBSS_OFFLOAD_DETECTION_DISABLED;
diff --git a/core/sme/inc/csr_api.h b/core/sme/inc/csr_api.h
index 059cfef00b24..9ff96e68ffa6 100644
--- a/core/sme/inc/csr_api.h
+++ b/core/sme/inc/csr_api.h
@@ -1169,7 +1169,6 @@ typedef struct tagCsrConfigParam {
uint8_t enableHtSmps;
uint8_t htSmps;
bool send_smps_action;
- bool ignore_peer_erp_info;
/*
* To enable/disable scanning only 2.4Ghz channels on first scan
*/
@@ -1203,10 +1202,7 @@ typedef struct tagCsrConfigParam {
uint8_t conc_custom_rule1;
uint8_t conc_custom_rule2;
uint8_t is_sta_connection_in_5gz_enabled;
- bool send_deauth_before_con;
- /* 802.11p enable */
- bool enable_dot11p;
uint8_t max_scan_count;
bool early_stop_scan_enable;
int8_t early_stop_scan_min_threshold;
@@ -1214,7 +1210,6 @@ typedef struct tagCsrConfigParam {
int8_t first_scan_bucket_threshold;
uint8_t fEnableDebugLog;
uint8_t max_intf_count;
- bool enable5gEBT;
bool enableSelfRecovery;
uint32_t f_sta_miracast_mcc_rest_time_val;
#ifdef FEATURE_AP_MCC_CH_AVOIDANCE
@@ -1261,8 +1256,6 @@ typedef struct tagCsrConfigParam {
uint16_t wlm_latency_enable;
uint16_t wlm_latency_level;
uint32_t wlm_latency_flags[CSR_NUM_WLM_LATENCY_LEVEL];
- bool qcn_ie_support;
- uint8_t fils_max_chan_guard_time;
uint16_t pkt_err_disconn_th;
bool is_force_1x1;
uint32_t disallow_duration;
diff --git a/core/sme/inc/csr_internal.h b/core/sme/inc/csr_internal.h
index 8ab0e307eab0..74c140294ba5 100644
--- a/core/sme/inc/csr_internal.h
+++ b/core/sme/inc/csr_internal.h
@@ -530,12 +530,10 @@ struct csr_config {
bool isRoamOffloadEnabled;
#endif
bool obssEnabled;
- bool ignore_peer_erp_info;
uint8_t conc_custom_rule1;
uint8_t conc_custom_rule2;
uint8_t is_sta_connection_in_5gz_enabled;
struct roam_ext_params roam_params;
- bool send_deauth_before_con;
bool early_stop_scan_enable;
int8_t early_stop_scan_min_threshold;
int8_t early_stop_scan_max_threshold;
@@ -566,8 +564,6 @@ struct csr_config {
bool enable_ul_ofdma;
bool enable_ul_mimo;
#endif
- bool qcn_ie_support;
- uint8_t fils_max_chan_guard_time;
uint16_t pkt_err_disconn_th;
bool is_force_1x1;
uint32_t disallow_duration;
diff --git a/core/sme/inc/sme_api.h b/core/sme/inc/sme_api.h
index 15a6b14aefb3..2c3011219a98 100644
--- a/core/sme/inc/sme_api.h
+++ b/core/sme/inc/sme_api.h
@@ -1316,8 +1316,6 @@ int sme_update_tx_bfee_nsts(mac_handle_t hal, uint8_t session_id,
void wlan_sap_enable_phy_error_logs(tHalHandle hal, uint32_t enable_log);
#ifdef WLAN_FEATURE_DSRC
-void sme_set_dot11p_config(tHalHandle hal, bool enable_dot11p);
-
QDF_STATUS sme_ocb_set_config(tHalHandle hHal, void *context,
ocb_callback callback,
struct sir_ocb_config *config);
@@ -1359,11 +1357,6 @@ sme_set_etsi13_srd_ch_in_master_mode(tHalHandle hal,
{
}
#else
-static inline void sme_set_dot11p_config(tHalHandle hal, bool enable_dot11p)
-{
- return;
-}
-
static inline QDF_STATUS sme_ocb_set_config(tHalHandle hHal, void *context,
ocb_callback callback,
struct sir_ocb_config *config)
diff --git a/core/sme/src/common/sme_api.c b/core/sme/src/common/sme_api.c
index 27e3023acc67..b6582778205f 100644
--- a/core/sme/src/common/sme_api.c
+++ b/core/sme/src/common/sme_api.c
@@ -8724,32 +8724,8 @@ void sme_get_command_q_status(tHalHandle hHal)
csr_nonscan_pending_ll_count(pMac));
}
-/**
- * sme_set_prefer_80MHz_over_160MHz() - API to set sta_prefer_80MHz_over_160MHz
- * @hal: The handle returned by macOpen
- * @sta_prefer_80MHz_over_160MHz: sta_prefer_80MHz_over_160MHz config param
- */
-void sme_set_prefer_80MHz_over_160MHz(tHalHandle hal,
- bool sta_prefer_80MHz_over_160MHz)
-{
- tpAniSirGlobal mac_ctx = PMAC_STRUCT(hal);
-
- mac_ctx->sta_prefer_80MHz_over_160MHz = sta_prefer_80MHz_over_160MHz;
-}
#ifdef WLAN_FEATURE_DSRC
-/**
- * sme_set_dot11p_config() - API to set the 802.11p config
- * @hHal: The handle returned by macOpen
- * @enable_dot11p: 802.11p config param
- */
-void sme_set_dot11p_config(tHalHandle hHal, bool enable_dot11p)
-{
- tpAniSirGlobal pMac = PMAC_STRUCT(hHal);
-
- pMac->enable_dot11p = enable_dot11p;
-}
-
/**
* copy_sir_ocb_config() - Performs deep copy of an OCB configuration
* @src: the source configuration
diff --git a/core/sme/src/csr/csr_api_roam.c b/core/sme/src/csr/csr_api_roam.c
index bda6d95a3b27..5e8a26a84d34 100644
--- a/core/sme/src/csr/csr_api_roam.c
+++ b/core/sme/src/csr/csr_api_roam.c
@@ -3050,8 +3050,6 @@ QDF_STATUS csr_change_default_config_param(tpAniSirGlobal pMac,
pMac->roam.configParam.rx_ldpc_enable = pParam->enable_rx_ldpc;
pMac->roam.configParam.disable_high_ht_mcs_2x2 =
pParam->disable_high_ht_mcs_2x2;
- pMac->roam.configParam.ignore_peer_erp_info =
- pParam->ignore_peer_erp_info;
pMac->roam.configParam.max_amsdu_num =
pParam->max_amsdu_num;
pMac->roam.configParam.nSelect5GHzMargin =
@@ -3082,10 +3080,7 @@ QDF_STATUS csr_change_default_config_param(tpAniSirGlobal pMac,
pParam->conc_custom_rule2;
pMac->roam.configParam.is_sta_connection_in_5gz_enabled =
pParam->is_sta_connection_in_5gz_enabled;
- pMac->roam.configParam.send_deauth_before_con =
- pParam->send_deauth_before_con;
- pMac->enable_dot11p = pParam->enable_dot11p;
pMac->roam.configParam.early_stop_scan_enable =
pParam->early_stop_scan_enable;
pMac->roam.configParam.early_stop_scan_min_threshold =
@@ -3147,7 +3142,6 @@ QDF_STATUS csr_change_default_config_param(tpAniSirGlobal pMac,
/* update interface configuration */
pMac->sme.max_intf_count = pParam->max_intf_count;
- pMac->enable5gEBT = pParam->enable5gEBT;
pMac->sme.enableSelfRecovery = pParam->enableSelfRecovery;
pMac->f_sta_miracast_mcc_rest_time_val =
@@ -3208,10 +3202,6 @@ QDF_STATUS csr_change_default_config_param(tpAniSirGlobal pMac,
pParam->enable_bcast_probe_rsp;
pMac->roam.configParam.is_fils_enabled =
pParam->is_fils_enabled;
- pMac->roam.configParam.qcn_ie_support =
- pParam->qcn_ie_support;
- pMac->roam.configParam.fils_max_chan_guard_time =
- pParam->fils_max_chan_guard_time;
pMac->roam.configParam.disallow_duration =
pParam->disallow_duration;
pMac->roam.configParam.rssi_channel_penalization =
@@ -3361,7 +3351,6 @@ QDF_STATUS csr_get_config_param(tpAniSirGlobal pMac, tCsrConfigParam *pParam)
cfg_params->enable_txbf_sap_mode;
pParam->enable_vht20_mcs9 = cfg_params->enable_vht20_mcs9;
pParam->enableVhtFor24GHz = cfg_params->enableVhtFor24GHz;
- pParam->ignore_peer_erp_info = cfg_params->ignore_peer_erp_info;
pParam->enable2x2 = cfg_params->enable2x2;
pParam->isFastTransitionEnabled = cfg_params->isFastTransitionEnabled;
pParam->RoamRssiDiff = cfg_params->RoamRssiDiff;
@@ -3412,7 +3401,6 @@ QDF_STATUS csr_get_config_param(tpAniSirGlobal pMac, tCsrConfigParam *pParam)
#ifdef WLAN_FEATURE_ROAM_OFFLOAD
pParam->isRoamOffloadEnabled = cfg_params->isRoamOffloadEnabled;
#endif
- pParam->enable_dot11p = pMac->enable_dot11p;
csr_set_channels(pMac, pParam);
pParam->obssEnabled = cfg_params->obssEnabled;
pParam->vendor_vht_sap =
@@ -3465,8 +3453,6 @@ QDF_STATUS csr_get_config_param(tpAniSirGlobal pMac, tCsrConfigParam *pParam)
pParam->conc_custom_rule2 = cfg_params->conc_custom_rule2;
pParam->is_sta_connection_in_5gz_enabled =
cfg_params->is_sta_connection_in_5gz_enabled;
- pParam->send_deauth_before_con =
- cfg_params->send_deauth_before_con;
pParam->max_scan_count = pMac->scan.max_scan_count;
pParam->first_scan_bucket_threshold =
pMac->first_scan_bucket_threshold;
@@ -3486,7 +3472,6 @@ QDF_STATUS csr_get_config_param(tpAniSirGlobal pMac, tCsrConfigParam *pParam)
pParam->auto_bmps_timer_val =
pMac->sme.ps_global_info.auto_bmps_timer_val;
pParam->fEnableDebugLog = pMac->fEnableDebugLog;
- pParam->enable5gEBT = pMac->enable5gEBT;
pParam->f_sta_miracast_mcc_rest_time_val =
pMac->f_sta_miracast_mcc_rest_time_val;
pParam->early_stop_scan_enable =
@@ -3527,10 +3512,6 @@ QDF_STATUS csr_get_config_param(tpAniSirGlobal pMac, tCsrConfigParam *pParam)
pMac->roam.configParam.enable_bcast_probe_rsp;
pParam->is_fils_enabled =
pMac->roam.configParam.is_fils_enabled;
- pParam->qcn_ie_support =
- pMac->roam.configParam.qcn_ie_support;
- pParam->fils_max_chan_guard_time =
- pMac->roam.configParam.fils_max_chan_guard_time;
pParam->disallow_duration =
pMac->roam.configParam.disallow_duration;
pParam->rssi_channel_penalization =
@@ -4267,7 +4248,6 @@ QDF_STATUS csr_roam_call_callback(tpAniSirGlobal pMac, uint32_t sessionId,
{
QDF_STATUS status = QDF_STATUS_SUCCESS;
#ifdef FEATURE_WLAN_DIAG_SUPPORT_CSR
- uint32_t rssi = 0;
WLAN_HOST_DIAG_EVENT_DEF(connectionStatus,
host_event_wlan_status_payload_type);
@@ -4390,9 +4370,7 @@ QDF_STATUS csr_roam_call_callback(tpAniSirGlobal pMac, uint32_t sessionId,
connectionStatus.channel =
roam_info->pBssDesc->channelId;
}
- if (cfg_set_int(pMac, WNI_CFG_CURRENT_RSSI,
- connectionStatus.rssi) == QDF_STATUS_E_FAILURE)
- sme_err("Can't pass WNI_CFG_CURRENT_RSSI to cfg");
+ pMac->mlme_cfg->sta.current_rssi = connectionStatus.rssi;
connectionStatus.qosCapability =
roam_info->u.pConnectedProfile->qosConnection;
@@ -4416,10 +4394,7 @@ QDF_STATUS csr_roam_call_callback(tpAniSirGlobal pMac, uint32_t sessionId,
|| (eCSR_ROAM_RESULT_MIC_FAILURE == u2)) {
qdf_mem_copy(&connectionStatus, &pMac->sme.eventPayload,
sizeof(host_event_wlan_status_payload_type));
- if (QDF_IS_STATUS_SUCCESS(wlan_cfg_get_int(pMac,
- WNI_CFG_CURRENT_RSSI, &rssi)))
- connectionStatus.rssi = rssi;
-
+ connectionStatus.rssi = pMac->mlme_cfg->sta.current_rssi;
connectionStatus.eventId = eCSR_WLAN_STATUS_DISCONNECT;
connectionStatus.reason = eCSR_REASON_MIC_ERROR;
WLAN_HOST_DIAG_EVENT_REPORT(&connectionStatus,
@@ -4428,10 +4403,7 @@ QDF_STATUS csr_roam_call_callback(tpAniSirGlobal pMac, uint32_t sessionId,
if (eCSR_ROAM_RESULT_FORCED == u2) {
qdf_mem_copy(&connectionStatus, &pMac->sme.eventPayload,
sizeof(host_event_wlan_status_payload_type));
- if (QDF_IS_STATUS_SUCCESS(wlan_cfg_get_int(pMac,
- WNI_CFG_CURRENT_RSSI, &rssi)))
- connectionStatus.rssi = rssi;
-
+ connectionStatus.rssi = pMac->mlme_cfg->sta.current_rssi;
connectionStatus.eventId = eCSR_WLAN_STATUS_DISCONNECT;
connectionStatus.reason = eCSR_REASON_USER_REQUESTED;
WLAN_HOST_DIAG_EVENT_REPORT(&connectionStatus,
@@ -4440,10 +4412,7 @@ QDF_STATUS csr_roam_call_callback(tpAniSirGlobal pMac, uint32_t sessionId,
if (eCSR_ROAM_RESULT_DISASSOC_IND == u2) {
qdf_mem_copy(&connectionStatus, &pMac->sme.eventPayload,
sizeof(host_event_wlan_status_payload_type));
- if (QDF_IS_STATUS_SUCCESS(wlan_cfg_get_int(pMac,
- WNI_CFG_CURRENT_RSSI, &rssi)))
- connectionStatus.rssi = rssi;
-
+ connectionStatus.rssi = pMac->mlme_cfg->sta.current_rssi;
connectionStatus.eventId = eCSR_WLAN_STATUS_DISCONNECT;
connectionStatus.reason = eCSR_REASON_DISASSOC;
if (roam_info)
@@ -4456,10 +4425,7 @@ QDF_STATUS csr_roam_call_callback(tpAniSirGlobal pMac, uint32_t sessionId,
if (eCSR_ROAM_RESULT_DEAUTH_IND == u2) {
qdf_mem_copy(&connectionStatus, &pMac->sme.eventPayload,
sizeof(host_event_wlan_status_payload_type));
- if (QDF_IS_STATUS_SUCCESS(wlan_cfg_get_int(pMac,
- WNI_CFG_CURRENT_RSSI, &rssi)))
- connectionStatus.rssi = rssi;
-
+ connectionStatus.rssi = pMac->mlme_cfg->sta.current_rssi;
connectionStatus.eventId = eCSR_WLAN_STATUS_DISCONNECT;
connectionStatus.reason = eCSR_REASON_DEAUTH;
if (roam_info)
@@ -17316,7 +17282,7 @@ QDF_STATUS csr_issue_add_sta_for_session_req(tpAniSirGlobal pMac,
add_sta_self_req->enable_bcast_probe_rsp =
pMac->roam.configParam.enable_bcast_probe_rsp;
add_sta_self_req->fils_max_chan_guard_time =
- pMac->roam.configParam.fils_max_chan_guard_time;
+ pMac->mlme_cfg->sta.fils_max_chan_guard_time;
add_sta_self_req->pkt_err_disconn_th =
pMac->roam.configParam.pkt_err_disconn_th;
add_sta_self_req->oce_feature_bitmap =
@@ -19517,7 +19483,7 @@ static void csr_update_driver_assoc_ies(tpAniSirGlobal mac_ctx,
ese_populate_addtional_ies(mac_ctx, session, req_buf);
/* Append QCN IE if g_support_qcn_ie INI is enabled */
- if (mac_ctx->roam.configParam.qcn_ie_support)
+ if (mac_ctx->mlme_cfg->sta.qcn_ie_support)
csr_append_assoc_ies(mac_ctx, req_buf, IEEE80211_ELEMID_VENDOR,
DOT11F_IE_QCN_IE_MAX_LEN,
qcn_ie);
diff --git a/core/wma/src/wma_dev_if.c b/core/wma/src/wma_dev_if.c
index ea0c0ae295dc..3dac1162d207 100644
--- a/core/wma/src/wma_dev_if.c
+++ b/core/wma/src/wma_dev_if.c
@@ -2401,12 +2401,7 @@ struct cdp_vdev *wma_vdev_attach(tp_wma_handle wma_handle,
WMA_LOGE("failed to set aggr sizes per ac(err=%d)",
status);
- if (wlan_cfg_get_int(mac, WNI_CFG_INFRA_STA_KEEP_ALIVE_PERIOD,
- &cfg_val) != QDF_STATUS_SUCCESS) {
- WMA_LOGE("Failed to get value for WNI_CFG_INFRA_STA_KEEP_ALIVE_PERIOD");
- cfg_val = DEFAULT_INFRA_STA_KEEP_ALIVE_PERIOD;
- }
-
+ cfg_val = mac->mlme_cfg->sta.sta_keep_alive_period;
wma_set_sta_keep_alive(wma_handle,
self_sta_req->session_id,
SIR_KEEP_ALIVE_NULL_PKT,
@@ -2784,14 +2779,8 @@ QDF_STATUS wma_vdev_start(tp_wma_handle wma,
intr[params.vdev_id].config.gtx_info.gtxRTMask[1] =
CFG_TGT_DEFAULT_GTX_VHT_MASK;
- if (wlan_cfg_get_int(mac_ctx, WNI_CFG_TGT_GTX_USR_CFG,
- &intr[params.vdev_id].config.gtx_info.gtxUsrcfg)
- != QDF_STATUS_SUCCESS) {
- intr[params.vdev_id].config.gtx_info.gtxUsrcfg =
- WNI_CFG_TGT_GTX_USR_CFG_STADEF;
- QDF_TRACE(QDF_MODULE_ID_WMA, QDF_TRACE_LEVEL_WARN,
- "Failed to get WNI_CFG_TGT_GTX_USR_CFG");
- }
+ intr[params.vdev_id].config.gtx_info.gtxUsrcfg =
+ mac_ctx->mlme_cfg->sta.tgt_gtx_usr_cfg;
intr[params.vdev_id].config.gtx_info.gtxPERThreshold =
CFG_TGT_DEFAULT_GTX_PER_THRESHOLD;
@@ -4348,8 +4337,8 @@ static void wma_add_bss_sta_mode(tp_wma_handle wma, tpAddBssParams add_bss)
wmi_unified_send_txbf(wma, &add_bss->staContext);
- pps_val = ((pMac->enable5gEBT << 31) & 0xffff0000) |
- (PKT_PWR_SAVE_5G_EBT & 0xffff);
+ pps_val = ((pMac->mlme_cfg->sta.enable_5g_ebt << 31) &
+ 0xffff0000) | (PKT_PWR_SAVE_5G_EBT & 0xffff);
status = wma_vdev_set_param(wma->wmi_handle, vdev_id,
WMI_VDEV_PARAM_PACKET_POWERSAVE,
pps_val);
diff --git a/core/wma/src/wma_mgmt.c b/core/wma/src/wma_mgmt.c
index 5de49c7cf34d..5d944480f04d 100644
--- a/core/wma/src/wma_mgmt.c
+++ b/core/wma/src/wma_mgmt.c
@@ -73,6 +73,8 @@
#include
#include "wma_twt.h"
#include "wlan_p2p_cfg_api.h"
+#include "cfg_ucfg_api.h"
+#include "cfg_mlme_sta.h"
/**
* wma_send_bcn_buf_ll() - prepare and send beacon buffer to fw for LL
@@ -897,9 +899,9 @@ void wma_set_sta_keep_alive(tp_wma_handle wma, uint8_t vdev_id,
return;
}
- if (timeperiod > WNI_CFG_INFRA_STA_KEEP_ALIVE_PERIOD_STAMAX) {
+ if (timeperiod > cfg_max(CFG_INFRA_STA_KEEP_ALIVE_PERIOD)) {
WMI_LOGE("Invalid period %d Max limit %d", timeperiod,
- WNI_CFG_INFRA_STA_KEEP_ALIVE_PERIOD_STAMAX);
+ cfg_max(CFG_INFRA_STA_KEEP_ALIVE_PERIOD));
return;
}
diff --git a/core/mac/src/pe/lim/lim_process_mlm_rsp_messages.c b/core/mac/src/pe/lim/lim_process_mlm_rsp_messages.c
index a38d5c6050b9..9b7003e313cb 100644
--- a/core/mac/src/pe/lim/lim_process_mlm_rsp_messages.c
+++ b/core/mac/src/pe/lim/lim_process_mlm_rsp_messages.c
@@ -2994,10 +2994,10 @@ static void lim_process_switch_channel_join_req(
lim_apply_configuration(mac_ctx, session_entry);
/*
* If send_deauth_before_con is enabled, Send Deauth first to AP if last
* disconnection was caused by HB failure.
*/
- if (mac_ctx->roam.configParam.send_deauth_before_con) {
+ if (mac_ctx->mlme_cfg->sta.deauth_before_connection) {
int apCount;
for (apCount = 0; apCount < 2; apCount++) {
@@ -2994,10 +2994,10 @@ static void lim_process_switch_channel_join_req(
lim_apply_configuration(mac_ctx, session_entry);
/*
- * If send_deauth_before_con is enabled, Send Deauth first to AP if last
- * disconnection was caused by HB failure.
+ * If deauth_before_connection is enabled, Send Deauth first to AP if
+ * last disconnection was caused by HB failure.
*/